@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -59,7 +59,9 @@
 /**                # Version 4.0  : from : 29 nov 2003     **/
 /**                                 to     10 mar 2005     **/
 /**                # Version 5.0  : from : 10 sep 2007     **/
-/**                                 to     27 feb 2008     **/
+/**                                 to     28 feb 2008     **/
+/**                # Version 5.1  : from : 21 jan 2008     **/
+/**                                 to     11 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -184,7 +186,7 @@ const Anum * const              termdisttab)      /*+ Terminal distance map
                                               archDecoArchDistE (archptr, i, 2 * j + 1) + 1) / 2;
 #ifdef SCOTCH_DEBUG_ARCH1
         else {                                    /* If both domain are terminals                  */
-          if (archDecoArchDist (archptr, i, j) == 0) { /* Distance value must br greater than zero */
+          if (archDecoArchDist (archptr, i, j) == 0) { /* Distance value must be greater than zero */
             errorPrint       ("archDecoArchBuild: invalid null distance");
             archDecoArchFree (archptr);
             return           (1);
@@ -211,12 +213,12 @@ archDecoArchLoad (
 ArchDeco * restrict const   archptr,
 FILE * restrict const       stream)
 {
-  Anum                        decotype;           /* Type of decomposition                            */
-  Anum                        termdomnbr;         /* Number of terminal domains (ie processors)       */
-  Anum                        termdommax;         /* Maximum domain number given to a terminal domain */
+  INT                         decotype;           /* Type of decomposition                            */
+  INT                         termdomnbr;         /* Number of terminal domains (ie processors)       */
+  INT                         termdommax;         /* Maximum domain number given to a terminal domain */
   ArchDecoTermVert * restrict termverttab;        /* Table of terminal vertex data                    */
   Anum * restrict             termdisttab;        /* Table of terminal-to-terminal distances          */
-  Anum                        i, j;
+  INT                         i, j;
 
 #ifdef SCOTCH_DEBUG_ARCH1
   if ((sizeof (ArchDeco)    > sizeof (ArchDummy)) ||
@@ -238,71 +240,85 @@ FILE * restrict const       stream)
   }
 
   if (decotype == 0) {                            /* If raw decomposition */
-    if (((termverttab = (ArchDecoTermVert *) memAlloc (termdomnbr * sizeof (ArchDecoTermVert)))                      == NULL) ||
-        ((termdisttab = (Anum *)             memAlloc ((((termdommax * (termdommax - 1)) / 2) + 1) * sizeof (Anum))) == NULL)) {
+    if (memAllocGroup ((void **) (void *)
+                       &termverttab, (size_t) (termdomnbr * sizeof (ArchDecoTermVert)),
+                       &termdisttab, (size_t) ((((termdommax * (termdommax - 1)) / 2) + 1) * sizeof (Anum)), NULL) == NULL) {
       errorPrint ("archDecoArchLoad: out of memory (1)");
-      if (termverttab != NULL)
-        memFree (termverttab);
-      archDecoArchFree (archptr);
-      return           (1);
+      return     (1);
     }
 
     for (i = 0; i < termdomnbr; i ++) {           /* For all declared terminals  */
-      if ((intLoad (stream, &termverttab[i].labl) != 1) || /* Read terminal data */
-	  (intLoad (stream, &termverttab[i].wght) != 1) ||
-	  (intLoad (stream, &termverttab[i].num)  != 1) ||
-          (termverttab[i].num < 1)                      ||
-          (termverttab[i].num > termdommax)) {
+      INT                 termvertlabl;
+      INT                 termvertwght;
+      INT                 termvertnum;
+
+      if ((intLoad (stream, &termvertlabl) != 1) || /* Read terminal data */
+          (intLoad (stream, &termvertwght) != 1) ||
+          (intLoad (stream, &termvertnum)  != 1) ||
+          (termvertnum < 1)                      ||
+          (termvertnum > termdommax)) {
         errorPrint       ("archDecoArchLoad: bad input (2)");
-        memFree          (termdisttab);
-        memFree          (termverttab);
-        archDecoArchFree (archptr);
+        memFree          (termverttab);           /* Free group leader */
         return           (1);
       }
+      termverttab[i].labl = (ArchDomNum) termvertlabl;
+      termverttab[i].wght = (Anum)       termvertwght;
+      termverttab[i].num  = (Anum)       termvertnum;
     }
 
     for (i = 0, j = (termdomnbr * (termdomnbr - 1)) / 2; i < j; i ++) { /* Read terminal distance map */
-      if ((intLoad (stream, &termdisttab[i]) != 1) ||
-          (termdisttab[i] < 1)) {
+      INT                 termdistval;
+
+      if ((intLoad (stream, &termdistval) != 1) ||
+          (termdistval < 1)) {
         errorPrint       ("archDecoArchLoad: bad input (3)");
-        memFree          (termdisttab);
-        memFree          (termverttab);
-        archDecoArchFree (archptr);
+        memFree          (termverttab);           /* Free group leader */
         return           (1);
       }
+      termdisttab[i] = (Anum) termdistval;
     }
 
     archDecoArchBuild (archptr, termdomnbr, termdommax, termverttab, termdisttab);
 
-    memFree (termdisttab);
-    memFree (termverttab);
+    memFree (termverttab);                        /* Free group leader */
   }
-  else {                                          /* If it is a compiled decomposition      */
-    if (((archptr->domverttab = (ArchDecoVert *) memAlloc (termdommax * sizeof (ArchDecoVert)))                      == NULL) ||
-        ((archptr->domdisttab = (Anum *)         memAlloc ((termdommax * (termdommax - 1) / 2 + 1) * sizeof (Anum))) == NULL)) {
+  else {                                          /* If it is a compiled decomposition */
+    if (memAllocGroup ((void **) (void *)
+                       &archptr->domverttab, (size_t) (termdommax * sizeof (ArchDecoVert)),
+                       &archptr->domdisttab, (size_t) ((((termdommax * (termdommax - 1)) / 2) + 1) * sizeof (Anum)), NULL) == NULL) {
       errorPrint       ("archDecoArchLoad: out of memory (2)");
-      archDecoArchFree (archptr);
       return           (1);
     }
-    archptr->domtermnbr = termdomnbr;
-    archptr->domvertnbr = termdommax;
+    archptr->flagval    = ARCHDECOFREE;
+    archptr->domtermnbr = (Anum) termdomnbr;
+    archptr->domvertnbr = (Anum) termdommax;
 
     for (i = 0; i < termdommax; i ++) {           /* Read domain array */
-      if ((intLoad (stream, &archptr->domverttab[i].labl) != 1) ||
-	  (intLoad (stream, &archptr->domverttab[i].size) != 1) ||
-	  (intLoad (stream, &archptr->domverttab[i].wght) != 1)) {
+      INT                 domvertlabl;
+      INT                 domvertsize;
+      INT                 domvertwght;
+
+      if ((intLoad (stream, &domvertlabl) != 1) ||
+	  (intLoad (stream, &domvertsize) != 1) ||
+	  (intLoad (stream, &domvertwght) != 1)) {
         errorPrint       ("archDecoArchLoad: bad input (4)");
         archDecoArchFree (archptr);
         return           (1);
       }
+      archptr->domverttab[i].labl = (ArchDomNum) domvertlabl;
+      archptr->domverttab[i].size = (Anum)       domvertsize;
+      archptr->domverttab[i].wght = (Anum)       domvertwght;
     }
 
     for (i = 0; i < (termdommax * (termdommax - 1)) / 2; i ++) { /* Read distance array */
-      if (intLoad (stream, &archptr->domdisttab[i]) != 1) {
+      INT                 domdistval;
+
+      if (intLoad (stream, &domdistval) != 1) {
         errorPrint       ("archDecoArchLoad: bad input (5)");
         archDecoArchFree (archptr);
         return           (1);
       }
+      archptr->domdisttab[i] = domdistval;
     }
   }
 
@@ -362,18 +378,18 @@ FILE * restrict const       stream)
   }
 #endif /* SCOTCH_DEBUG_ARCH1 */
 
-  if (fprintf (stream, "1\n%ld\t%ld\n",           /* Write number of domains */
-               (long) archptr->domtermnbr,
-               (long) archptr->domvertnbr) == EOF) {
+  if (fprintf (stream, "1\n" ANUMSTRING "\t" ANUMSTRING "\n", /* Write number of domains */
+               (Anum) archptr->domtermnbr,
+               (Anum) archptr->domvertnbr) == EOF) {
     errorPrint ("archDecoArchSave: bad output (1)");
     return     (1);
   }
 
   for (i = 0; i < archptr->domvertnbr; i ++) {    /* Write domain array */
-    if (fprintf (stream, "%ld\t%ld\t%ld\n",
-                 (long) archptr->domverttab[i].labl,
-                 (long) archptr->domverttab[i].size,
-                 (long) archptr->domverttab[i].wght) == EOF) {
+    if (fprintf (stream, ANUMSTRING "\t" ANUMSTRING "\t" ANUMSTRING "\n",
+                 (Anum) archptr->domverttab[i].labl,
+                 (Anum) archptr->domverttab[i].size,
+                 (Anum) archptr->domverttab[i].wght) == EOF) {
       errorPrint ("archDecoArchSave: bad output (2)");
       return     (1);
     }
@@ -381,8 +397,8 @@ FILE * restrict const       stream)
 
   j = (archptr->domvertnbr * (archptr->domvertnbr - 1)) / 2;
   for (i = 0; i < j; i ++) {                      /* Write distance array */
-    if (fprintf (stream, "%ld%c",
-                 (long) archptr->domdisttab[i],
+    if (fprintf (stream, ANUMSTRING "%c",
+                 (Anum) archptr->domdisttab[i],
                  (((i % 8) == 7) && (i != (j - 1))) ? '\n' : '\t') == EOF) {
       errorPrint ("archDecoArchSave: bad output (3)");
       return     (1);
@@ -526,8 +542,8 @@ const ArchDeco * const      archptr,
 const ArchDecoDom * const   domptr,
 FILE * restrict const       stream)
 {
-  if (fprintf (stream, "%ld ",
-               (long) domptr->num) == EOF) {
+  if (fprintf (stream, ANUMSTRING " ",
+               (Anum) domptr->num) == EOF) {
     errorPrint ("archDecoDomSave: bad output");
     return     (1);
   }
@@ -559,3 +575,22 @@ ArchDecoDom * restrict const  dom1ptr)
 
   return (0);
 }
+
+/* This function creates the MPI_Datatype for
+** decomposition-described domains.
+** It returns:
+** - 0  : if type could be created.
+** - 1  : on error.
+*/
+
+#ifdef SCOTCH_PTSCOTCH
+int
+archDecoDomMpiType (
+const ArchDeco * const        archptr,
+MPI_Datatype * const          typeptr)
+{
+  *typeptr = ANUM_MPI;
+
+  return (0);
+}
+#endif /* SCOTCH_PTSCOTCH */
