@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -58,8 +58,8 @@
 /**                                 to     01 oct 1998     **/
 /**                # Version 4.0  : from : 09 jan 2004     **/
 /**                                 to     10 mar 2005     **/
-/**                # Version 5.0  : from : 27 feb 2008     **/
-/**                                 to     27 feb 2008     **/
+/**                # Version 5.1  : from : 21 jan 2008     **/
+/**                                 to     11 aug 2010     **/
 /**                                                        **/
 /**   NOTES      : # The vertices of the (dX,dY) mesh are  **/
 /**                  numbered as terminals so that         **/
@@ -136,9 +136,9 @@ FILE * restrict const       stream)
   }
 #endif /* SCOTCH_DEBUG_ARCH1 */
 
-  if (fprintf (stream, "%ld %ld ",
-               (long) archptr->c[0],
-               (long) archptr->c[1]) == EOF) {
+  if (fprintf (stream, ANUMSTRING " " ANUMSTRING " ",
+               (Anum) archptr->c[0],
+               (Anum) archptr->c[1]) == EOF) {
     errorPrint ("archMesh2ArchSave: bad output");
     return     (1);
   }
@@ -273,9 +273,9 @@ const ArchMesh2 * const     archptr,
 const ArchMesh2Dom * const  domptr,
 FILE * restrict const       stream)
 {
-  if (fprintf (stream, "%ld %ld %ld %ld ",
-               (long) domptr->c[0][0], (long) domptr->c[1][0],
-               (long) domptr->c[0][1], (long) domptr->c[1][1]) == EOF) {
+  if (fprintf (stream, ANUMSTRING " " ANUMSTRING " " ANUMSTRING " " ANUMSTRING " ",
+               (Anum) domptr->c[0][0], (Anum) domptr->c[1][0],
+               (Anum) domptr->c[0][1], (Anum) domptr->c[1][1]) == EOF) {
     errorPrint ("archMesh2DomSave: bad output");
     return     (1);
   }
@@ -298,12 +298,21 @@ const ArchMesh2Dom * const    domptr,
 ArchMesh2Dom * restrict const dom0ptr,
 ArchMesh2Dom * restrict const dom1ptr)
 {
-  if ((domptr->c[0][0] == domptr->c[0][1]) &&     /* Return if cannot bipartition more */
-      (domptr->c[1][0] == domptr->c[1][1]))
+  Anum                dimsiz[2];
+  int                 dimval;                     /* Dimension along which to split */
+
+  dimsiz[0] = domptr->c[0][1] - domptr->c[0][0];
+  dimsiz[1] = domptr->c[1][1] - domptr->c[1][0];
+
+  if ((dimsiz[0] | dimsiz[1]) == 0)               /* Return if cannot bipartition more */
     return (1);
 
-  if ((domptr->c[0][1] - domptr->c[0][0]) >       /* Split domain in two along largest dimension */
-      (domptr->c[1][1] - domptr->c[1][0])) {
+  dimval = 1;
+  if ((dimsiz[0] > dimsiz[1]) ||                  /* Split domain in two along largest dimension */
+      ((dimsiz[0] == dimsiz[1]) && (archptr->c[0] > archptr->c[1])))
+    dimval = 0;
+
+  if (dimval == 0) {                              /* Split across the X dimension */
     dom0ptr->c[0][0] = domptr->c[0][0];
     dom0ptr->c[0][1] = (domptr->c[0][0] + domptr->c[0][1]) / 2;
     dom1ptr->c[0][0] = dom0ptr->c[0][1] + 1;
@@ -311,7 +320,7 @@ ArchMesh2Dom * restrict const dom1ptr)
     dom0ptr->c[1][0] = dom1ptr->c[1][0] = domptr->c[1][0];
     dom0ptr->c[1][1] = dom1ptr->c[1][1] = domptr->c[1][1];
   }
-  else {
+  else {                                          /* Split across the Y dimension */
     dom0ptr->c[0][0] = dom1ptr->c[0][0] = domptr->c[0][0];
     dom0ptr->c[0][1] = dom1ptr->c[0][1] = domptr->c[0][1];
     dom0ptr->c[1][0] = domptr->c[1][0];
@@ -386,6 +395,25 @@ ArchMesh2Dom * restrict const dom1ptr)
   return (0);
 }
 
+/* This function creates the MPI_Datatype for
+** 2D mesh domains.
+** It returns:
+** - 0  : if type could be created.
+** - 1  : on error.
+*/
+
+#ifdef SCOTCH_PTSCOTCH
+int
+archMesh2DomMpiType (
+const ArchMesh2 * const       archptr,
+MPI_Datatype * const          typeptr)
+{
+  MPI_Type_contiguous (4, ANUM_MPI, typeptr);
+
+  return (0);
+}
+#endif /* SCOTCH_PTSCOTCH */
+
 /***********************************************/
 /*                                             */
 /* These are the 3-dimensional mesh routines. */
@@ -443,8 +471,8 @@ FILE * restrict const       stream)
   }
 #endif /* SCOTCH_DEBUG_ARCH1 */
 
-  if (fprintf (stream, "%ld %ld %ld ",
-               (long) archptr->c[0], (long) archptr->c[1], (long) archptr->c[2]) == EOF) {
+  if (fprintf (stream, ANUMSTRING " " ANUMSTRING " " ANUMSTRING " ",
+               (Anum) archptr->c[0], (Anum) archptr->c[1], (Anum) archptr->c[2]) == EOF) {
     errorPrint ("archMesh3ArchSave: bad output");
     return     (1);
   }
@@ -590,9 +618,9 @@ const ArchMesh3 * const     archptr,
 const ArchMesh3Dom * const  domptr,
 FILE * restrict const       stream)
 {
-  if (fprintf (stream, "%ld %ld %ld %ld %ld %ld ",
-               (long) domptr->c[0][0], (long) domptr->c[1][0], (long) domptr->c[2][0],
-               (long) domptr->c[0][1], (long) domptr->c[1][1], (long) domptr->c[2][1]) == EOF) {
+  if (fprintf (stream, ANUMSTRING " " ANUMSTRING " " ANUMSTRING " " ANUMSTRING " " ANUMSTRING " " ANUMSTRING " ",
+               (Anum) domptr->c[0][0], (Anum) domptr->c[1][0], (Anum) domptr->c[2][0],
+               (Anum) domptr->c[0][1], (Anum) domptr->c[1][1], (Anum) domptr->c[2][1]) == EOF) {
     errorPrint ("archMesh3DomSave: bad output");
     return     (1);
   }
@@ -615,21 +643,28 @@ const ArchMesh3Dom * const    domptr,
 ArchMesh3Dom * restrict const dom0ptr,
 ArchMesh3Dom * restrict const dom1ptr)
 {
-  int                 i;
+  Anum                dimsiz[3];
+  int                 dimtmp;
+  int                 dimval;
 
-  if ((domptr->c[0][0] == domptr->c[0][1]) &&     /* Return if cannot bipartition more */
-      (domptr->c[1][0] == domptr->c[1][1]) &&
-      (domptr->c[2][0] == domptr->c[2][1]))
+  dimsiz[0] = domptr->c[0][1] - domptr->c[0][0];
+  dimsiz[1] = domptr->c[1][1] - domptr->c[1][0];
+  dimsiz[2] = domptr->c[2][1] - domptr->c[2][0];
+
+  if ((dimsiz[0] | dimsiz[1] | dimsiz[2]) == 0)   /* Return if cannot bipartition more */
     return (1);
 
-  i = ((domptr->c[1][1] - domptr->c[1][0]) >      /* Find largest dimension */
-       (domptr->c[0][1] - domptr->c[0][0]))
-    ? 1 : 0;
-  if  ((domptr->c[2][1] - domptr->c[2][0]) >
-       (domptr->c[i][1] - domptr->c[i][0]))
-    i = 2;
+  dimval = (archptr->c[1] > archptr->c[0]) ? 1 : 0; /* Assume all subdomain dimensions are equal */
+  if (archptr->c[2] > archptr->c[dimval])         /* Find priviledged dimension                  */
+    dimval = 2;
 
-  if (i == 0) {                                   /* Split domain in two along largest dimension */
+  dimtmp = dimval;                                /* Find best dimension */
+  if (dimsiz[(dimtmp + 1) % 3] > dimsiz[dimval])
+    dimval = (dimtmp + 1) % 3;
+  if (dimsiz[(dimtmp + 2) % 3] > dimsiz[dimval])
+    dimval = (dimtmp + 2) % 3;
+
+  if (dimval == 0) {                              /* Split domain in two along largest dimension */
     dom0ptr->c[0][0] = domptr->c[0][0];
     dom0ptr->c[0][1] = (domptr->c[0][0] + domptr->c[0][1]) / 2;
     dom1ptr->c[0][0] = dom0ptr->c[0][1] + 1;
@@ -641,7 +676,7 @@ ArchMesh3Dom * restrict const dom1ptr)
     dom0ptr->c[2][0] = dom1ptr->c[2][0] = domptr->c[2][0];
     dom0ptr->c[2][1] = dom1ptr->c[2][1] = domptr->c[2][1];
   }
-  else if (i == 1) {
+  else if (dimval == 1) {
     dom0ptr->c[0][0] = dom1ptr->c[0][0] = domptr->c[0][0];
     dom0ptr->c[0][1] = dom1ptr->c[0][1] = domptr->c[0][1];
 
@@ -668,3 +703,22 @@ ArchMesh3Dom * restrict const dom1ptr)
 
   return (0);
 }
+
+/* This function creates the MPI_Datatype for
+** 3D mesh domains.
+** It returns:
+** - 0  : if type could be created.
+** - 1  : on error.
+*/
+
+#ifdef SCOTCH_PTSCOTCH
+int
+archMesh3DomMpiType (
+const ArchMesh3 * const       archptr,
+MPI_Datatype * const          typeptr)
+{
+  MPI_Type_contiguous (6, ANUM_MPI, typeptr);
+
+  return (0);
+}
+#endif /* SCOTCH_PTSCOTCH */
