@@ -1,4 +1,4 @@
-/* Copyright 2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2010,2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,7 +41,7 @@
 /**                evenly as possible.                     **/
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 16 jul 2010     **/
-/**                                 to   : 29 aug 2010     **/
+/**                                 to   : 15 apr 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -93,6 +93,7 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
   Gnum                  complocloaddlt;           /* Load of vertices moved locally  */
   Gnum                  compglbloaddlt;
   Gnum                  compglbloaddltmax;
+  Gnum                  compglbloaddltmat;
   Gnum                  commlocgain;
   Gnum                  commlocgainextn;
   Gnum                  fronlocnbr;
@@ -115,11 +116,18 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
   Gnum * restrict const       fronloctab = grafptr->fronloctab;
   GraphPart * restrict const  partgsttax = grafptr->partgsttax;
 
-  compglbloaddltmax = (Gnum) ((double) grafptr->compglbload0avg * paraptr->deltval);
+  partval = (grafptr->compglbload0dlt > 0) ? 1 : 0; /* Get number of underloaded part to receive vertices */
 
-  if ((abs (grafptr->compglbload0dlt) <= compglbloaddltmax) || /* If nothing to do */
-      (grafptr->fronglbnbr == 0))                 /* Or if no current frontier     */
-    return (0);                                   /* This algorithm is useless     */
+  compglbloaddltmax = (Gnum) ((double) grafptr->compglbload0avg * paraptr->deltval);
+  compglbloaddltmat = (partval == 0)
+                      ? (grafptr->compglbload0avg - grafptr->compglbload0min)
+                      : (grafptr->compglbload0max - grafptr->compglbload0avg);
+  if (compglbloaddltmax > compglbloaddltmat)
+    compglbloaddltmax = compglbloaddltmat;
+
+  if ((abs (grafptr->compglbload0dlt) < compglbloaddltmax) || /* If nothing to do */
+      (grafptr->fronglbnbr == 0))                 /* Or if no current frontier    */
+    return (0);                                   /* This algorithm is useless    */
 
   if (dgraphGhst (&grafptr->s) != 0) {            /* Compute ghost edge array if not already present */
     errorPrint ("bdgraphBipartEx: cannot compute ghost edge array");
@@ -139,8 +147,8 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
                      &frstloctab, (size_t) (gainsiz * sizeof (Gnum)),
                      &nextloctab, (size_t) (grafptr->fronlocnbr   * sizeof (Gnum)),
                      &loadglbtab, (size_t) (grafptr->s.procglbnbr * sizeof (Gnum)),
-                     &movegsttab, (size_t) (flagSize (grafptr->s.vertgstnbr) * sizeof (int)),
-                     &flagloctab, (size_t) (flagSize (grafptr->s.vertlocnbr) * sizeof (int)),
+                     &movegsttab, (size_t) (flagSize (grafptr->s.vertgstnbr + grafptr->s.baseval) * sizeof (int)), /* TRICK: use based vertices as flag array indices */
+                     &flagloctab, (size_t) (flagSize (grafptr->s.vertlocnbr + grafptr->s.baseval) * sizeof (int)),
                      &sorttab,    (size_t) (sortsiz), NULL) == NULL) {
     errorPrint ("bdgraphBipartEx: out of memory");
     cheklocval = 1;
@@ -149,8 +157,8 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
     memSet (gainloctab,  0, gainsiz * sizeof (Gnum)); /* Initialize gain array  */
     memSet (frstloctab, ~0, gainsiz * sizeof (Gnum)); /* Initialize linked list */
     memSet (nextloctab, ~0, grafptr->fronlocnbr * sizeof (Gnum));
-    memSet (movegsttab,  0, flagSize (grafptr->s.vertgstnbr) * sizeof (int));
-    memSet (flagloctab,  0, flagSize (grafptr->s.vertlocnbr) * sizeof (int));
+    memSet (movegsttab,  0, flagSize (grafptr->s.vertgstnbr + grafptr->s.baseval) * sizeof (int)); /* TRICK: based sizes */
+    memSet (flagloctab,  0, flagSize (grafptr->s.vertlocnbr + grafptr->s.baseval) * sizeof (int));
   }
 
 #ifdef SCOTCH_DEBUG_BDGRAPH1
@@ -167,7 +175,6 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
     return (1);
   }
 
-  partval = (grafptr->compglbload0dlt > 0) ? 1 : 0; /* Get number of underloaded part to receive vertices */
   domdist = (Gnum) grafptr->domdist;
 
   edgegsttax = grafptr->s.edgegsttax;
