@@ -1,4 +1,4 @@
-/* Copyright 2007,2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2010,2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : bdgraph_bipart_sq.c                     **/
 /**                                                        **/
 /**   AUTHOR     : Jun-Ho HER                              **/
+/**                Francois PELLEGRINI                     **/
 /**                                                        **/
 /**   FUNCTION   : This module computes a bipartition of a **/
 /**                given bipartitioned distributed graph   **/
@@ -44,7 +45,7 @@
 /**                result obtained.                        **/
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 27 dec 2007     **/
-/**                                 to     30 jul 2010     **/
+/**                                 to     14 apr 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -130,7 +131,7 @@ Bdgraph * const                     dgrfptr,      /*+ Distributed graph +*/
 const BdgraphBipartSqParam * const  paraptr)      /*+ Method parameters +*/
 {
   Bgraph            cgrfdat;                      /* Centralized bipartitioned graph structure           */
-  Gnum              reduloctab[9];                /* Local array for best bipartition data (7 for Bcast) */
+  Gnum              reduloctab[6];                /* Local array for best bipartition data (7 for Bcast) */
   Gnum              reduglbtab[6];                /* Global array for best bipartition data              */
   MPI_Datatype      besttypedat;                  /* Data type for finding best bipartition              */
   MPI_Op            bestoperdat;                  /* Handle of MPI operator for finding best bipartition */
@@ -218,28 +219,21 @@ const BdgraphBipartSqParam * const  paraptr)      /*+ Method parameters +*/
   bestprocnum = (int) reduglbtab[2];
   if (dgrfptr->s.proclocnum == bestprocnum) {     /* If process holds best partition */
     reduloctab[0] = cgrfdat.compload0;            /* Global values to share          */
-    reduloctab[1] = cgrfdat.compload0avg;
-    reduloctab[2] = cgrfdat.compload0dlt;
-    reduloctab[3] = cgrfdat.compsize0;
-    reduloctab[4] = cgrfdat.commload;
-    reduloctab[5] = cgrfdat.commgainextn;
-    reduloctab[6] = cgrfdat.commgainextn0;
-    reduloctab[7] = cgrfdat.commloadextn0;
-    reduloctab[8] = cgrfdat.fronnbr;
+    reduloctab[1] = cgrfdat.compsize0;
+    reduloctab[2] = cgrfdat.commload;
+    reduloctab[3] = cgrfdat.commgainextn;
+    reduloctab[4] = cgrfdat.fronnbr;
   }
-  if (MPI_Bcast (reduloctab, 9, GNUM_MPI, bestprocnum, dgrfptr->s.proccomm) != MPI_SUCCESS) {
+  if (MPI_Bcast (reduloctab, 5, GNUM_MPI, bestprocnum, dgrfptr->s.proccomm) != MPI_SUCCESS) {
     errorPrint ("bdgraphBipartSq: communication error (4)");
     return     (1);
   }
-  dgrfptr->compglbload0     = reduloctab[0];
-  dgrfptr->compglbload0avg  = reduloctab[1];
-  dgrfptr->compglbload0dlt  = reduloctab[2];
-  dgrfptr->compglbsize0     = reduloctab[3];
-  dgrfptr->commglbload      = reduloctab[4];
-  dgrfptr->commglbgainextn  = reduloctab[5];
-  dgrfptr->commglbgainextn0 = reduloctab[6];
-  dgrfptr->commglbloadextn0 = reduloctab[7];
-  dgrfptr->fronglbnbr       = reduloctab[8];
+  dgrfptr->compglbload0    = reduloctab[0];
+  dgrfptr->compglbload0dlt = reduloctab[0] - dgrfptr->compglbload0avg;
+  dgrfptr->compglbsize0    = reduloctab[1];
+  dgrfptr->commglbload     = reduloctab[2];
+  dgrfptr->commglbgainextn = reduloctab[3];
+  dgrfptr->fronglbnbr      = reduloctab[4];
 
   if (commScatterv (cgrfdat.parttax, dgrfptr->s.proccnttab, dgrfptr->s.procdsptab, GRAPHPART_MPI, /* No base for sending as procdsptab holds based values */
                     dgrfptr->partgsttax + dgrfptr->s.baseval, dgrfptr->s.vertlocnbr, GRAPHPART_MPI,
