@@ -1,4 +1,4 @@
-/* Copyright 2007-2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2007-2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,7 +41,7 @@
 /**                bipartitioning methods.                 **/
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 10 sep 2007     **/
-/**                                 to   : 14 aug 2010     **/
+/**                                 to   : 15 apr 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -84,7 +84,7 @@ static union {
 static union {
   BdgraphBipartDfParam      param;
   StratNodeMethodData       padding;
-} bdgraphbipartstdefaultdf = { { 500, 1.0, 0.0, 0.0 } };
+} bdgraphbipartstdefaultdf = { { 500, 1.0, 0.0, BDGRAPHBIPARTDFTYPEBAL } };
 
 static union {
   BdgraphBipartExParam      param;
@@ -135,6 +135,10 @@ static StratParamTab        bdgraphbipartstparatab[] = { /* Method parameter lis
                                 (byte *) &bdgraphbipartstdefaultdf.param,
                                 (byte *) &bdgraphbipartstdefaultdf.param.cremval,
                                 NULL },
+                              { BDGRAPHBIPARTSTMETHDF,  STRATPARAMCASE,   "type",
+                                (byte *) &bdgraphbipartstdefaultdf.param,
+                                (byte *) &bdgraphbipartstdefaultdf.param.typeval,
+                                (void *) "bk" },
                               { BDGRAPHBIPARTSTMETHEX,  STRATPARAMINT,    "sbbt",
                                 (byte *) &bdgraphbipartstdefaultex.param,
                                 (byte *) &bdgraphbipartstdefaultex.param.sbbtnbr,
@@ -183,6 +187,14 @@ static StratParamTab        bdgraphbipartstcondtab[] = { /* Active graph conditi
                                 (byte *) &bdgraphdummy,
                                 (byte *) &bdgraphdummy.compglbload0,
                                 NULL },
+                              { STRATNODECOND,       STRATPARAMINT,    "lmin0",
+                                (byte *) &bdgraphdummy,
+                                (byte *) &bdgraphdummy.compglbload0min,
+                                NULL },
+                              { STRATNODECOND,       STRATPARAMINT,    "lmax0",
+                                (byte *) &bdgraphdummy,
+                                (byte *) &bdgraphdummy.compglbload0max,
+                                NULL },
                               { STRATNODECOND,       STRATPARAMINT,    "edge",
                                 (byte *) &bdgraphdummy,
                                 (byte *) &bdgraphdummy.s.edgeglbnbr,
@@ -300,11 +312,38 @@ const Strat * restrict const  strat)              /*+ Bipartitioning strategy
       bdgraphStoreUpdt     (grafptr, &savetab[1]); /* Restore initial bipartition           */
       o2 = bdgraphBipartSt (grafptr, strat->data.select.strat[1]); /* Apply second strategy */
 
-      if ((o == 0) || (o2 == 0)) {                /* If at least one method did bipartition     */
-        if ( (savetab[0].commglbload <  grafptr->commglbload) || /* If first strategy is better */
-            ((savetab[0].commglbload == grafptr->commglbload) &&
-             (abs (savetab[0].compglbload0dlt) < abs (grafptr->compglbload0dlt))))
+      if ((o == 0) || (o2 == 0)) {                /* If at least one method did bipartition */
+        Gnum                compglbload0;
+	int                 b0;
+        int                 b1;
+
+        compglbload0 = grafptr->compglbload0avg + savetab[0].compglbload0dlt;
+        b0 = ((compglbload0 < grafptr->compglbload0min) ||
+              (compglbload0 > grafptr->compglbload0max)) ? 1 : o;
+        compglbload0 = grafptr->compglbload0avg + savetab[1].compglbload0dlt;
+        b1 = ((compglbload0 < grafptr->compglbload0min) ||
+              (compglbload0 > grafptr->compglbload0max)) ? 1 : o2;
+
+        do {                                      /* Do we want to restore partition 0 ? */
+          if (b0 > b1)
+            break;
+          if (b0 == b1) {                         /* If both are valid or invalid        */
+            if (b0 == 0) {                        /* If both are valid                   */
+              if ( (savetab[0].commglbload >  grafptr->commglbload) || /* Compare on cut */
+                  ((savetab[0].commglbload == grafptr->commglbload) &&
+                   (abs (savetab[0].compglbload0dlt) > abs (grafptr->compglbload0dlt))))
+                break;
+            }
+            else {                                /* If both are invalid */
+              if ( (abs (savetab[0].compglbload0dlt) >  abs (grafptr->compglbload0dlt)) || /* Compare on imbalance */
+                  ((abs (savetab[0].compglbload0dlt) == abs (grafptr->compglbload0dlt)) &&
+                   (savetab[0].commglbload > grafptr->commglbload)))
+                break;
+            }
+          }
+
           bdgraphStoreUpdt (grafptr, &savetab[0]); /* Restore its result */
+        }  while (0);
       }
       if (o2 < o)                                 /* o = min(o,o2): if one biparts, then bipart */
         o = o2;                                   /* Else if one stops, then stop, else error   */
