@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,7 +45,7 @@
 /**                # Version 2.0  : from : 01 jul 2008     **/
 /**                                 to   : 01 jul 2008     **/
 /**                # Version 5.1  : from : 22 nov 2008     **/
-/**                                 to   : 22 nov 2008     **/
+/**                                 to   : 27 jun 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -55,6 +55,9 @@
 
 #define COMMON_MEMORY
 
+#ifndef COMMON_NOMODULE
+#include "module.h"
+#endif /* COMMON_NOMODULE */
 #include "common.h"
 
 /*********************************/
