@@ -1,4 +1,4 @@
-/* Copyright 2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -40,9 +40,9 @@
 /**                Jerome LACOSTE (P0.1)                   **/
 /**                Cedric CHEVALIER                        **/
 /**                                                        **/
-/**   FUNCTION   : These lines are the data declarations   **/
-/**                for the distributed graph general       **/
-/**                purpose routines.                       **/
+/**   FUNCTION   : This module contains the distributed    **/
+/**                graph data structure handling           **/
+/**                routines.                               **/
 /**                                                        **/
 /**    DATES     : # Version P0.0 : from : 01 apr 1997     **/
 /**                                 to     01 apr 1997     **/
@@ -50,6 +50,8 @@
 /**                                 to     20 jun 1998     **/
 /**                # Version 5.0  : from : 16 feb 2005     **/
 /**                                 to   : 17 jul 2008     **/
+/**                # Version 5.1  : from : 21 jun 2008     **/
+/**                                 to   : 30 jul 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -97,32 +99,6 @@ MPI_Comm                    proccomm)             /* Communicator to be used for
   return (0);
 }
 
-/* This routine destroys a distributed graph structure.
-** It is not a collective routine, as no communication
-** is needed to perform the freeing of memory structures.
-** Private data are always destroyed. If this is not
-** wanted, use dgraphFree() instead.
-** It returns:
-** - VOID  : in all cases.
-*/
-
-void
-dgraphExit (
-Dgraph * restrict const     grafptr)
-{
-  if (grafptr->procdsptab != NULL)                /* Private data are always freed on exit   */
-    memFree (grafptr->procdsptab);                /* Free group leader of graph private data */
-  if ((grafptr->flagval & DGRAPHFREECOMM) != 0)   /* If communicator has to be freed         */
-    MPI_Comm_free (&grafptr->proccomm);           /* Free it                                 */
-
-  grafptr->flagval |= DGRAPHFREEEXIT;             /* Do not preserve private fields since we exit for good        */
-  dgraphFree (grafptr);                           /* Free graph public data (flagval may be corrupted afterwards) */
-
-#ifdef SCOTCH_DEBUG_DGRAPH1
-  memSet (grafptr, 0, sizeof (Dgraph));
-#endif /* SCOTCH_DEBUG_DGRAPH1 */
-}
-
 /* This routine frees the public data of the given
 ** distributed graph, but not its private data.
 ** It is not a collective routine, as no communication
@@ -131,20 +107,11 @@ Dgraph * restrict const     grafptr)
 ** - VOID  : in all cases.
 */
 
+static
 void
-dgraphFree (
+dgraphFree2 (
 Dgraph * restrict const     grafptr)
 {
-  MPI_Comm            proccomm;                   /* Data for temporarily saving private data */
-  int                 procglbnbr;
-  int                 proclocnum;
-  int * restrict      proccnttab;                 /* Communication arrays are "int" and not "Gnum" because of MPI */
-  int * restrict      procdsptab;
-  int * restrict      procvrttab;
-  int * restrict      procngbtab;
-  int * restrict      procrcvtab;
-  int * restrict      procsndtab;
-
   if ((grafptr->flagval & DGRAPHFREETABS) != 0) { /* If local arrays must be freed */
     if (grafptr->vertloctax != NULL)
       memFree (grafptr->vertloctax + grafptr->baseval);
@@ -165,16 +132,34 @@ Dgraph * restrict const     grafptr)
 	memFree (grafptr->edloloctax + grafptr->baseval);
     }
   }
+  if ((grafptr->flagval & DGRAPHFREEPSID) != 0) { /* If process send arrays must be freed */
+    if (grafptr->procsidtab != NULL)
+      memFree (grafptr->procsidtab);
+  }
   if ((grafptr->flagval & DGRAPHFREEEDGEGST) != 0) { /* If ghost array must be freed */
     if (grafptr->edgegsttax != NULL)
       memFree (grafptr->edgegsttax + grafptr->baseval);
   }
-  if (grafptr->procsidtab != NULL)                /* procsidtab is built on demand */
-    memFree (grafptr->procsidtab);
+}
 
-  if ((grafptr->flagval & DGRAPHFREEEXIT) != 0)   /* If we are exiting, no use to go any further */
-    return;
+void
+dgraphFree (
+Dgraph * restrict const     grafptr)
+{
+  DgraphFlag          flagval;
+  MPI_Comm            proccomm;                   /* Data for temporarily saving private data */
+  int                 procglbnbr;
+  int                 proclocnum;
+  Gnum * restrict     proccnttab;                 /* Some communication arrays are "int" and not "Gnum" because of MPI */
+  Gnum * restrict     procdsptab;
+  Gnum * restrict     procvrttab;
+  int * restrict      procngbtab;
+  int * restrict      procrcvtab;
+  int * restrict      procsndtab;
 
+  dgraphFree2 (grafptr);                          /* Free all user fields */
+
+  flagval    = grafptr->flagval & (DGRAPHFREEPRIV | DGRAPHFREECOMM);
   proccomm   = grafptr->proccomm;                 /* Save private fields only */
   procglbnbr = grafptr->procglbnbr;
   proclocnum = grafptr->proclocnum;
@@ -187,7 +172,8 @@ Dgraph * restrict const     grafptr)
 
   memSet (grafptr, 0, sizeof (Dgraph));           /* Reset all of the graph structure */
 
-  grafptr->proccomm   = proccomm;                 /* Restore private fields */
+  grafptr->flagval    = flagval;                  /* Restore private fields */
+  grafptr->proccomm   = proccomm;
   grafptr->procglbnbr = procglbnbr;
   grafptr->proclocnum = proclocnum;
   grafptr->proccnttab = proccnttab;
@@ -199,3 +185,29 @@ Dgraph * restrict const     grafptr)
 
   return;
 }
+
+/* This routine destroys a distributed graph structure.
+** It is not a collective routine, as no communication
+** is needed to perform the freeing of memory structures.
+** Private data are always destroyed. If this is not
+** wanted, use dgraphFree() instead.
+** It returns:
+** - VOID  : in all cases.
+*/
+
+void
+dgraphExit (
+Dgraph * restrict const     grafptr)
+{
+  if ((grafptr->flagval & DGRAPHFREEPRIV) != 0)   /* If private data has to be freed */
+    if (grafptr->procdsptab != NULL)
+      memFree (grafptr->procdsptab);              /* Free group leader of graph private data */
+  if ((grafptr->flagval & DGRAPHFREECOMM) != 0)   /* If communicator has to be freed         */
+    MPI_Comm_free (&grafptr->proccomm);           /* Free it                                 */
+
+  dgraphFree2 (grafptr);
+
+#ifdef SCOTCH_DEBUG_DGRAPH1
+  memSet (grafptr, 0, sizeof (Dgraph));
+#endif /* SCOTCH_DEBUG_DGRAPH1 */
+}
