@@ -55,7 +55,7 @@
 /**                # Version 5.0  : from : 22 jul 2005     **/
 /**                                 to   : 03 aug 2007     **/
 /**                # Version 5.1  : from : 11 nov 2007     **/
-/**                                 to   : 04 nov 2010     **/
+/**                                 to   : 20 feb 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -63,6 +63,10 @@
 
 #define PTSCOTCH_FOLD_DUP                         /* Activate folding on coarsening */
 
+#ifndef SCOTCH_COMM_PTOP_RAT
+#define SCOTCH_COMM_PTOP_RAT        0.25          /* Percentage under which point-to-point is allowed */
+#endif /* SCOTCH_COMM_PTOP_RAT */
+
 /*
 ** The defines.
 */
@@ -80,6 +84,7 @@
 #define DGRAPHVERTGROUP             0x0040        /* All vertex arrays grouped           */
 #define DGRAPHEDGEGROUP             0x0080        /* All edge arrays grouped             */
 #define DGRAPHFREEALL               (DGRAPHFREEPRIV | DGRAPHFREECOMM | DGRAPHFREETABS | DGRAPHFREEPSID  | DGRAPHFREEEDGEGST)
+#define DGRAPHCOMMPTOP              0x0100        /* Use point-to-point collective communication */
 
 #define DGRAPHBITSUSED              0x00FF        /* Significant bits for plain distributed graph routines               */
 #define DGRAPHBITSNOTUSED           0x0100        /* Value above which bits not used by plain distributed graph routines */
@@ -119,10 +124,11 @@ typedef enum DgraphTag_ {
   TAGDATALOCTAB,                                  /*+ Generic data message     +*/
   TAGOK,                                          /*+ Positive answer          +*/
   TAGBAD,                                         /*+ Negative answer          +*/
-  TAGCOARSEN = 100,                               /*+ Tag class for coarsening +*/
-  TAGMATCH   = 200,                               /*+ Tag class for matching   +*/
-  TAGFOLD    = 300,                               /*+ Tag class for folding    +*/
-  TAGBAND    = 400                                /*+ Tag class for band graph +*/
+  TAGHALO    = 100,                               /*+ Tag class for halo       +*/
+  TAGCOARSEN = 200,                               /*+ Tag class for coarsening +*/
+  TAGMATCH   = 300,                               /*+ Tag class for matching   +*/
+  TAGFOLD    = 400,                               /*+ Tag class for folding    +*/
+  TAGBAND    = 500                                /*+ Tag class for band graph +*/
 } DgraphTag;
 
 /*+ The graph flag type. +*/
