@@ -1,4 +1,4 @@
-/* Copyright 2007,2009,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2009-2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -42,7 +42,7 @@
 /**   DATES      : # Version 5.0  : from : 23 may 2006     **/
 /**                                 to   : 10 sep 2007     **/
 /**                # Version 5.1  : from : 18 jan 2009     **/
-/**                                 to   : 30 jul 2010     **/
+/**                                 to   : 10 sep 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -65,18 +65,22 @@
 
 int
 dgraphFoldComm (
-const Dgraph * restrict const       grafptr,
-const int                           partval,      /* 0 for first half, 1 for second half                     */
-int * restrict const                commtypval,   /* Process will be sender or receiver                      */
-DgraphFoldCommData * restrict       commdattab,   /* Slots for communication                                 */
-Gnum * restrict const               commvrttab,   /* Slots of starting global vertex send indices            */
-Gnum * restrict const               proccnttab,   /* Receive count array, for receivers                      */
-int * restrict const                vertadjptr,   /* Number of adjustment ranges, for receivers              */
-Gnum * restrict const               vertadjtab,   /* Pointer to global index adjustment array, for receivers */
-Gnum * restrict const               vertdlttab)   /* Pointer to global delta adjustment array, for receivers */
+const Dgraph * restrict const                 grafptr,
+const int                                     partval, /* 0 for first half, 1 for second half                        */
+int * restrict const                          commptr, /* Pointer to maximum number of communications per process    */
+int * restrict const                          commtypval, /* Process will be sender or receiver                      */
+DgraphFoldCommData *restrict * restrict const commdatptr, /* Slots for communication                                 */
+Gnum *restrict * restrict const               commvrtptr, /* Slots of starting global vertex send indices            */
+Gnum * restrict const                         proccnttab, /* Receive count array, for receivers                      */
+int * restrict const                          vertadjnbrptr, /* Number of adjustment ranges, for receivers           */
+Gnum * restrict * restrict const              vertadjptr, /* Pointer to global index adjustment array, for receivers */
+Gnum * restrict * restrict const              vertdltptr) /* Pointer to global delta adjustment array, for receivers */
 {
+  int                           commmax;          /* Maximum number of communications per process        */
   int                           procnum;
-  DgraphFoldCommData * restrict procsrttab;       /* Sort array                                                        */
+  Gnum * restrict               commvrttab;
+  DgraphFoldCommData * restrict commdattab;
+  DgraphFoldCommData * restrict procsrttab;       /* Sort array                                          */
   int                           procsndbas;
   int                           procsndmnd;
   int                           procsndidx;
@@ -84,10 +88,14 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
   int                           procrcvnnd;
   int                           procrcvidx;
   int                           fldprocnbr;
-  int * restrict                vertprmtab;       /* Permutation array for adjustment range computations               */
+  Gnum * restrict               vertadjtab;
+  Gnum * restrict               vertdlttab;
+  int * restrict                vertprmtab;       /* Permutation array for adjustment range computations */
   int                           i;
 #ifdef SCOTCH_DEBUG_DGRAPH2
   DgraphFoldCommData * restrict procchktab;
+  int                           chekloctab[2];
+  int                           chekglbtab[2];
 
   if (grafptr->procglbnbr < 2) {
     errorPrint ("dgraphFoldComm: invalid parameters");
@@ -95,13 +103,8 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
   }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
 
-  if (memAllocGroup ((void **) (void *)
-                     &procsrttab, (size_t) (grafptr->procglbnbr * sizeof (DgraphFoldCommData)),
-#ifdef SCOTCH_DEBUG_DGRAPH2
-                     &procchktab, (size_t) (grafptr->procglbnbr * sizeof (DgraphFoldCommData) * DGRAPHFOLDCOMMNBR),
-#endif /* SCOTCH_DEBUG_DGRAPH2 */
-                     &vertprmtab, (size_t) (grafptr->procglbnbr * sizeof (int) * (DGRAPHFOLDCOMMNBR + 1)), NULL) == NULL) { /* Oversized, but don't care */
-    errorPrint ("dgraphFoldComm: out of memory");
+  if ((procsrttab = memAlloc (grafptr->procglbnbr * sizeof (DgraphFoldCommData))) == NULL) {
+    errorPrint ("dgraphFoldComm: out of memory (1)");
     return     (1);
   }
 
@@ -130,71 +133,14 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
   *commtypval = ((grafptr->proclocnum >= procrcvbas) && (grafptr->proclocnum < procrcvnnd)) ? DGRAPHFOLDCOMMRECV : DGRAPHFOLDCOMMSEND;
 #ifdef SCOTCH_DEBUG_DGRAPH2
   if ((*commtypval == DGRAPHFOLDCOMMRECV) &&
-      ((proccnttab == NULL) || (vertadjtab == NULL) || (vertdlttab == NULL))) {
+      ((proccnttab == NULL) || (vertadjptr == NULL) || (vertdltptr == NULL))) {
     errorPrint ("dgraphFoldComm: internal error (1)");
     memFree    (procsrttab);                      /* Free group leader */
     return     (1);
   }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
 
-  for (i = 0; i < DGRAPHFOLDCOMMNBR; i ++) {      /* Assume we will perform no communication at all */
-    commdattab[i].procnum = -1;
-    commdattab[i].vertnbr = 0;
-  }
-  if (proccnttab != NULL) {                       /* If we are a receiver process, start filling count and adjustment arrays */
-    int                   procrcvtmp;
-
-    memSet (vertprmtab, ~0, (DGRAPHFOLDCOMMNBR + 1) * fldprocnbr * sizeof (int)); /* Reset adjustment index arrays */
-    memSet (vertadjtab, ~0, DGRAPHFOLDCOMMNBR * grafptr->procglbnbr * sizeof (Gnum));
-
-    for (procrcvtmp = procrcvbas; procrcvtmp < procrcvnnd; procrcvtmp ++) { /* Fill count and adjustment arrays for receiver processes slots */
-      vertadjtab[procrcvtmp * DGRAPHFOLDCOMMNBR] = grafptr->procvrttab[procrcvtmp];
-      vertdlttab[procrcvtmp * DGRAPHFOLDCOMMNBR] =
-      proccnttab[procrcvtmp - procrcvbas]        = grafptr->proccnttab[procrcvtmp];
-      vertprmtab[(procrcvtmp - procrcvbas) * (DGRAPHFOLDCOMMNBR + 1)] = procrcvtmp * DGRAPHFOLDCOMMNBR;
-    }
-  }
-
-  for (procrcvidx = procrcvbas; procrcvidx < (procrcvnnd - 1); procrcvidx ++, procrcvnnd --) { /* Overloaded receiver vertices will re-send some of their load */
-    Gnum                  vertsndnbr;             /* Potential overload of receiver process */
-    int                   procrcvnum;
-    int                   procsndnum;
-
-    procsndidx = procrcvnnd - 1;
-    vertsndnbr = procsrttab[procsndidx].vertnbr - DATASIZE (grafptr->vertglbnbr, fldprocnbr, procsndidx - procrcvbas);
-    if (vertsndnbr <= 0)                          /* If no further overload to improve, exit loop */
-      break;
-
-    procrcvnum = procsrttab[procrcvidx].procnum;
-    procsndnum = procsrttab[procsndidx].procnum;
-
-    procsrttab[procrcvidx].vertnbr = - (procsrttab[procrcvidx].vertnbr + vertsndnbr); /* Flag as having had a communication */
-    if (proccnttab != NULL) {                     /* If we are a receiver process, fill count and adjustment arrays         */
-      proccnttab[procrcvnum - procrcvbas] += vertsndnbr;
-      proccnttab[procsndnum - procrcvbas] -= vertsndnbr; /* Vertices are transferred between receiver processes */
-      vertadjtab[procsndnum * DGRAPHFOLDCOMMNBR + 1] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndnbr;
-      vertdlttab[procsndnum * DGRAPHFOLDCOMMNBR + 1] = vertsndnbr;
-      vertdlttab[procsndnum * DGRAPHFOLDCOMMNBR]    -= vertsndnbr;
-      vertprmtab[(procrcvnum - procrcvbas) * (DGRAPHFOLDCOMMNBR + 1) + 1] = procsndnum * DGRAPHFOLDCOMMNBR + 1;
-
-      if (procsndnum == grafptr->proclocnum) {    /* If we are the sender receiver process */
-        *commtypval = DGRAPHFOLDCOMMSEND | DGRAPHFOLDCOMMRECV; /* Indicate it              */
-        commdattab[0].procnum = procrcvnum;       /* Record communication                  */
-        commdattab[0].vertnbr = vertsndnbr;
-        commvrttab[0] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndnbr; /* Set starting global index of vertices to be sent */
-      }
-      else if (procrcvnum == grafptr->proclocnum) { /* If we are the receiver receiver process */
-        commdattab[0].procnum = procsndnum;       /* Record communication                      */
-        commdattab[0].vertnbr = vertsndnbr;
-        commvrttab[0] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndnbr; /* Set starting global index of vertices to be sent */
-      }
-    }
-  }
-
-  while ((procsndmnd < procsndbas) && (procsrttab[procsndmnd].vertnbr == 0)) /* Do not account for empty sender processes */
-    procsndmnd ++;
-
-  if (procsndmnd < procsndbas) {                  /* If there are sender processes */
+  for (commmax = DGRAPHFOLDCOMMNBR, commdattab = NULL; ; commmax ++) { /* Start with small number of communications per process */
     int                   procrcvnum;
     int                   procsndnum;
     int                   procsndnxt;             /* Index of next sender to process after current sender                */
@@ -203,6 +149,83 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
     Gnum                  vertsndrmn;             /* Remaining number of vertices to send from current sending process   */
     int                   flagrcvval;             /* Number of messages already sent by receiver and sender              */
     int                   flagsndval;
+    int                   commtmp;
+
+    if (commdattab != NULL)
+      memFree (commdattab);
+
+    commtmp = (proccnttab == NULL) ? 0 : commmax;
+    if (memAllocGroup ((void **) (void *)
+                       &commdattab, (size_t) (commmax * sizeof (DgraphFoldCommData)),
+                       &commvrttab, (size_t) (commmax * sizeof (Gnum)),
+                       &vertadjtab, (size_t) (commtmp * grafptr->procglbnbr * sizeof (Gnum)),
+                       &vertdlttab, (size_t) (commtmp * grafptr->procglbnbr * sizeof (Gnum)),
+#ifdef SCOTCH_DEBUG_DGRAPH2
+                       &procchktab, (size_t) (commmax * grafptr->procglbnbr * sizeof (DgraphFoldCommData)),
+#endif /* SCOTCH_DEBUG_DGRAPH2 */
+                       &vertprmtab, (size_t) ((commmax + 1) * fldprocnbr * sizeof (int)), NULL) == NULL) {
+      errorPrint ("dgraphFoldComm: out of memory (2)");
+      memFree    (procsrttab);
+      return     (1);
+    }
+
+    for (i = 0; i < commmax; i ++) {              /* Assume we will perform no communication at all */
+      commdattab[i].procnum = -1;
+      commdattab[i].vertnbr = 0;
+    }
+    if (proccnttab != NULL) {                     /* If we are a receiver process, start filling count and adjustment arrays */
+      int                   procrcvtmp;
+
+      memSet (vertprmtab, ~0, (commmax + 1) * fldprocnbr * sizeof (int)); /* Reset adjustment index arrays */
+      memSet (vertadjtab, ~0, commmax * grafptr->procglbnbr * sizeof (Gnum));
+
+      for (procrcvtmp = procrcvbas; procrcvtmp < procrcvnnd; procrcvtmp ++) { /* Fill count and adjustment arrays for receiver processes slots */
+        vertadjtab[procrcvtmp * commmax]    = grafptr->procvrttab[procrcvtmp];
+        vertdlttab[procrcvtmp * commmax]    =
+        proccnttab[procrcvtmp - procrcvbas] = grafptr->proccnttab[procrcvtmp];
+        vertprmtab[(procrcvtmp - procrcvbas) * (commmax + 1)] = procrcvtmp * commmax;
+      }
+    }
+
+    for (procrcvidx = procrcvbas; procrcvidx < (procrcvnnd - 1); procrcvidx ++, procrcvnnd --) { /* Overloaded receiver vertices will re-send some of their load */
+      Gnum                  vertsndnbr;           /* Potential overload of receiver process */
+
+      procsndidx = procrcvnnd - 1;
+      vertsndnbr = procsrttab[procsndidx].vertnbr - DATASIZE (grafptr->vertglbnbr, fldprocnbr, procsndidx - procrcvbas);
+      if (vertsndnbr <= 0)                        /* If no further overload to improve, exit loop */
+        break;
+
+      procrcvnum = procsrttab[procrcvidx].procnum;
+      procsndnum = procsrttab[procsndidx].procnum;
+
+      procsrttab[procrcvidx].vertnbr = - (procsrttab[procrcvidx].vertnbr + vertsndnbr); /* Flag as having had a communication */
+      if (proccnttab != NULL) {                   /* If we are a receiver process, fill count and adjustment arrays           */
+        proccnttab[procrcvnum - procrcvbas] += vertsndnbr;
+        proccnttab[procsndnum - procrcvbas] -= vertsndnbr; /* Vertices are transferred between receiver processes */
+        vertadjtab[procsndnum * commmax + 1] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndnbr;
+        vertdlttab[procsndnum * commmax + 1] = vertsndnbr;
+        vertdlttab[procsndnum * commmax]    -= vertsndnbr;
+        vertprmtab[(procrcvnum - procrcvbas) * (commmax + 1) + 1] = procsndnum * commmax + 1;
+
+        if (procsndnum == grafptr->proclocnum) {  /* If we are the sender receiver process */
+          *commtypval = DGRAPHFOLDCOMMSEND | DGRAPHFOLDCOMMRECV; /* Indicate it            */
+          commdattab[0].procnum = procrcvnum;     /* Record communication                  */
+          commdattab[0].vertnbr = vertsndnbr;
+          commvrttab[0] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndnbr; /* Set starting global index of vertices to be sent */
+        }
+        else if (procrcvnum == grafptr->proclocnum) { /* If we are the receiver receiver process */
+          commdattab[0].procnum = procsndnum;     /* Record communication                        */
+          commdattab[0].vertnbr = vertsndnbr;
+          commvrttab[0] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndnbr; /* Set starting global index of vertices to be sent */
+        }
+      }
+    }
+
+    while ((procsndmnd < procsndbas) && (procsrttab[procsndmnd].vertnbr == 0)) /* Do not account for empty sender processes */
+      procsndmnd ++;
+
+    if (procsndmnd >= procsndbas)                 /* If there are no more sender processes       */
+      break;                                      /* We have completed communication computation */
 
     procsndidx = procsndbas - 1;
     procsndnxt = procsndidx - 1;
@@ -227,20 +250,21 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
       int                 flagsndnxt;
 
 #ifdef SCOTCH_DEBUG_DGRAPH2
-      if (flagrcvval + flagsndval >= (DGRAPHFOLDCOMMNBR * 2)) {
+      if (flagrcvval + flagsndval >= (commmax * 2)) {
         errorPrint ("dgraphFoldComm: internal error (2)");
-        memFree    (procsrttab);                  /* Free group leader */
+        memFree    (commdattab);                  /* Free group leader */
+        memFree    (procsrttab);
         return     (1);
       }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
 
       vertrcvrmn = (vertglbavg > vertglbsum) ? (vertglbavg - vertglbsum) : 0; /* Remaining space on receiver */
-      mesgrcvrmn = (vertsndrmn >= vertrcvrmn) ? (DGRAPHFOLDCOMMNBR - 1) : (DGRAPHFOLDCOMMNBR - 2);
+      mesgrcvrmn = (vertsndrmn >= vertrcvrmn) ? (commmax - 1) : (commmax - 2);
       if ((procsndidx > procsndmnd) &&            /* If there remains small messages to be considered          */
           (((flagsndval == 0) &&                  /* If sender has not sent anything yet or just started       */
             (flagrcvval < mesgrcvrmn)) ||         /* And receiver has space for larger messages to come        */
            ((flagrcvval == 0) &&                  /* Or if receiver has not received anything yet              */
-            (flagsndval < (DGRAPHFOLDCOMMNBR - 2)))) && /* And sender has enough slots to send                 */
+            (flagsndval < (commmax - 2)))) &&     /* And sender has enough slots to send                       */
           (vertrcvrmn >= procsrttab[procsndmnd].vertnbr)) { /* And if receiver can hold small message entirely */
         procsndnxt = procsndidx;                  /* Current large message will be processed next time         */
         procsndidx = procsndmnd;                  /* Process smallest message available to date                */
@@ -254,9 +278,9 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
       else {
         flagsndnxt = 0;
         vertsndnxt = 0;                           /* Next sender will not have been interrupted by a small message */
-        vertsndnbr = ((flagsndval >= (DGRAPHFOLDCOMMNBR - 1)) || /* If last chance to send for this process        */
-                      (((procrcvnnd - procrcvidx) * (DGRAPHFOLDCOMMNBR - 1) - flagrcvval) <= (procsndidx - procsndmnd))) /* Or if too few communications remain with sender receivers accounted for */
-                     ? vertsndrmn                   /* Send all of the vertices to be sent     */
+        vertsndnbr = ((flagsndval >= (commmax - 1)) || /* If last chance to send for this process                  */
+                      (((procrcvnnd - procrcvidx) * (commmax - 1) - flagrcvval) <= (procsndidx - procsndmnd))) /* Or if too few communications remain with sender receivers accounted for */
+                     ? vertsndrmn                 /* Send all of the vertices to be sent       */
                      : MIN (vertsndrmn, vertrcvrmn); /* Else just send what the receiver needs */
       }
       procsndnum = procsrttab[procsndidx].procnum;
@@ -264,9 +288,9 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
       if (vertsndnbr > 0) {                       /* If useful communication can take place                         */
         if (proccnttab != NULL) {                 /* If we are a receiver process, fill count and adjustment arrays */
           proccnttab[procrcvnum - procrcvbas] += vertsndnbr;
-          vertadjtab[procsndnum * DGRAPHFOLDCOMMNBR + flagsndval] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndrmn;
-          vertdlttab[procsndnum * DGRAPHFOLDCOMMNBR + flagsndval] = vertsndnbr;
-          vertprmtab[(procrcvnum - procrcvbas) * (DGRAPHFOLDCOMMNBR + 1) + 1 + flagrcvval] = procsndnum * DGRAPHFOLDCOMMNBR + flagsndval;
+          vertadjtab[procsndnum * commmax + flagsndval] = grafptr->procvrttab[procsndnum] + grafptr->proccnttab[procsndnum] - vertsndrmn;
+          vertdlttab[procsndnum * commmax + flagsndval] = vertsndnbr;
+          vertprmtab[(procrcvnum - procrcvbas) * (commmax + 1) + 1 + flagrcvval] = procsndnum * commmax + flagsndval;
 
           if (procrcvnum == grafptr->proclocnum) { /* If we are the receiver process */
             commdattab[flagrcvval].procnum = procsndnum; /* Record communication     */
@@ -285,32 +309,19 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
         flagrcvval ++;
       }
       if (vertsndrmn <= 0) {                      /* If sending process has sent everything */
-#ifndef SCOTCH_DEBUG_DGRAPH2
-        if (procsndnum == grafptr->proclocnum) {  /* If we are the sending process              */
-          memFree (procsrttab);                   /* Free group leader for senders if not debug */
-          return  (0);                            /* Return as we do not need the count array   */
-        }
-#endif /* SCOTCH_DEBUG_DGRAPH2 */
-        procsndidx = procsndnxt;                  /* Process next vertex to send           */
-        if (procsndidx < procsndmnd)              /* If was last sending process, end loop */
+        procsndidx = procsndnxt;                  /* Process next vertex to send            */
+        if (procsndidx < procsndmnd)              /* If was last sending process, end loop  */
           break;
         procsndnxt = procsndidx - 1;              /* Prepare next sender process  */
         flagsndval = flagsndnxt;                  /* Skip to next sending process */
         vertsndrmn = procsrttab[procsndidx].vertnbr - vertsndnxt;
       }
-      if ((flagrcvval >= DGRAPHFOLDCOMMNBR) ||    /* If receiver cannot receive more                                 */
+      if ((flagrcvval >= commmax) ||              /* If receiver cannot receive more                                 */
           ((vertglbsum >= vertglbavg) &&          /* Or has received what it needed and is not forced to accept more */
-	   (((procrcvnnd - procrcvidx) * (DGRAPHFOLDCOMMNBR - 1) - flagrcvval) > (procsndidx - procsndmnd)))) {
-        if (++ procrcvidx >= procrcvnnd) {        /* If was last receiver, exit loop and go finalizing communication arrays */
-#ifndef SCOTCH_DEBUG_DGRAPH2
-          if ((procsndidx > procsndmnd) || (vertsndrmn > 0)) { /* If there remains a sender vertex which has yet something to send */
-            errorPrint ("dgraphFoldComm: internal error (3)");
-            memFree    (procsrttab);              /* Free group leader */
-            return     (1);
-          }
-#endif /* SCOTCH_DEBUG_DGRAPH2 */
+           (((procrcvnnd - procrcvidx) * (commmax - 1) - flagrcvval) > (procsndidx - procsndmnd)))) {
+        if (++ procrcvidx >= procrcvnnd)          /* If was last receiver, exit loop and go finalizing communication arrays */
           break;
-        }
+
         procrcvnum  = procsrttab[procrcvidx].procnum; /* Skip to next receiver process */
         vertglbavg += DATASIZE (grafptr->vertglbnbr, fldprocnbr, procrcvidx - procrcvbas);
         if (procsrttab[procrcvidx].vertnbr >= 0) { /* If receiver did not receive from a sender receiver */
@@ -323,13 +334,32 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
         }
       }
     }
+
+    if ((procsndidx <= procsndmnd) && (vertsndrmn <= 0)) /* If no sender vertex which has something to send remains */
+      break;                                      /* Exit the loop on increasing number of communications           */
   }
 
+#ifdef SCOTCH_DEBUG_DGRAPH2
+  chekloctab[0] = - commmax;
+  chekloctab[1] =   commmax;
+  if (MPI_Allreduce (chekloctab, chekglbtab, 2, MPI_INT, MPI_MAX, grafptr->proccomm) != MPI_SUCCESS) {
+    errorPrint ("dgraphFoldComm: communication error");
+    memFree    (commdattab);                      /* Free group leader */
+    return     (1);
+  }
+  if ((chekglbtab[0] != chekloctab[0]) ||
+      (chekglbtab[1] != chekloctab[1])) {
+    errorPrint ("dgraphFoldComm: internal error (3)");
+    memFree    (commdattab);                      /* Free group leader */
+    return     (1);
+  }
+#endif /* SCOTCH_DEBUG_DGRAPH2 */
+
   if (proccnttab != NULL) {                       /* If we are a receiver process                  */
     int                   vertadjnbr;             /* Number of adjustment slots                    */
     Gnum                  vertadjsum;             /* Current new starting position of current slot */
 
-    for (procnum = 0, vertadjsum = grafptr->baseval; procnum < ((DGRAPHFOLDCOMMNBR + 1) * fldprocnbr); procnum ++) {
+    for (procnum = 0, vertadjsum = grafptr->baseval; procnum < ((commmax + 1) * fldprocnbr); procnum ++) {
       int                   vertprmnum;
       Gnum                  vertadjtmp;
 
@@ -342,7 +372,7 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
       vertadjsum += vertadjtmp;
     }
 
-    for (procnum = vertadjnbr = 0; procnum < (DGRAPHFOLDCOMMNBR * grafptr->procglbnbr); procnum ++) { /* Compact vertex adjustment arrays */
+    for (procnum = vertadjnbr = 0; procnum < (commmax * grafptr->procglbnbr); procnum ++) { /* Compact vertex adjustment arrays */
       if (vertadjtab[procnum] != -1) {
         vertadjtab[vertadjnbr] = vertadjtab[procnum];
         vertdlttab[vertadjnbr] = vertdlttab[procnum];
@@ -350,55 +380,61 @@ Gnum * restrict const               vertdlttab)   /* Pointer to global delta adj
       }
     }
     vertadjtab[vertadjnbr] = grafptr->procvrttab[grafptr->procglbnbr]; /* Set upper bound on global vertex indices */
-    *vertadjptr = vertadjnbr;
+
+    *vertadjnbrptr = vertadjnbr;
+    *vertadjptr    = vertadjtab;
+    *vertdltptr    = vertdlttab;
   }
+  *commdatptr = commdattab;                       /* Set group leader */
+  *commvrtptr = commvrttab;
+  *commptr    = commmax;
+
+  memFree (procsrttab);
 
 #ifdef SCOTCH_DEBUG_DGRAPH2
   if (proccnttab == NULL) {                       /* If we are a sender process       */
     Gnum                  vertsndnbr;             /* Number of vertices actually sent */
     int                   i;
 
-    for (i = 0, vertsndnbr = 0; (i < DGRAPHFOLDCOMMNBR) && (commdattab[i].procnum != -1); i ++)
+    for (i = 0, vertsndnbr = 0; (i < commmax) && (commdattab[i].procnum >= 0); i ++)
       vertsndnbr += commdattab[i].vertnbr;
     if (vertsndnbr != grafptr->vertlocnbr) {
       errorPrint ("dgraphFoldComm: internal error (4)");
-      memFree    (procsrttab);                    /* Free group leader */
+      memFree    (commdattab);                    /* Free group leader */
       return     (1);
     }
   }
-  if (MPI_Allgather (commdattab, 2 * DGRAPHFOLDCOMMNBR, GNUM_MPI,
-                     procchktab, 2 * DGRAPHFOLDCOMMNBR, GNUM_MPI, grafptr->proccomm) != MPI_SUCCESS) {
+  if (MPI_Allgather (commdattab, 2 * commmax, GNUM_MPI,
+                     procchktab, 2 * commmax, GNUM_MPI, grafptr->proccomm) != MPI_SUCCESS) {
     errorPrint ("dgraphFoldComm: communication error");
-    memFree    (procsrttab);                      /* Free group leader */
+    memFree    (commdattab);                      /* Free group leader */
     return     (1);
   }
 
   for (procnum = 0; procnum < grafptr->procglbnbr; procnum ++) {
     int                   commnum;
 
-    for (commnum = 0; (commnum < DGRAPHFOLDCOMMNBR) && (procchktab[DGRAPHFOLDCOMMNBR * procnum + commnum].procnum != -1); commnum ++) {
+    for (commnum = 0; (commnum < commmax) && (procchktab[commmax * procnum + commnum].procnum != -1); commnum ++) {
       Gnum                  procend;
       Gnum                  vertnbr;
       int                   commend;
 
-      procend = procchktab[DGRAPHFOLDCOMMNBR * procnum + commnum].procnum;
-      vertnbr = procchktab[DGRAPHFOLDCOMMNBR * procnum + commnum].vertnbr;
+      procend = procchktab[commmax * procnum + commnum].procnum;
+      vertnbr = procchktab[commmax * procnum + commnum].vertnbr;
 
-      for (commend = 0; commend < DGRAPHFOLDCOMMNBR; commend ++) {
-        if ((procchktab[DGRAPHFOLDCOMMNBR * procend + commend].procnum == procnum) &&
-            (procchktab[DGRAPHFOLDCOMMNBR * procend + commend].vertnbr == vertnbr))
+      for (commend = 0; commend < commmax; commend ++) {
+        if ((procchktab[commmax * procend + commend].procnum == procnum) &&
+            (procchktab[commmax * procend + commend].vertnbr == vertnbr))
           break;
       }
-      if (commend >= DGRAPHFOLDCOMMNBR) {
+      if (commend >= commmax) {
         errorPrint ("dgraphFoldComm: internal error (5)");
-        memFree    (procsrttab);                  /* Free group leader */
+        memFree    (commdattab);                  /* Free group leader */
         return     (1);
       }
     }
   }
 #endif /* SCOTCH_DEBUG_DGRAPH2 */
 
-  memFree (procsrttab);                           /* Free group leader for receiver processes or all in case of debug */
-
   return (0);
 }
