@@ -1,4 +1,4 @@
-/* Copyright 2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2007-2009 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,6 +41,8 @@
 /**                                                        **/
 /**                # Version  5.0 : from : 28 apr 2007     **/
 /**                                 to   : 24 mar 2008     **/
+/**                # Version  5.1 : from : 23 jun 2008     **/
+/**                                 to   : 27 jan 2009     **/
 /**                                                        **/
 /************************************************************/
 
@@ -135,17 +137,15 @@ const DgraphFlag            flagval)              /* Graph loading flags
     errorPrint ("dgraphLoad: inconsistent graph file version value");
     return     (1);
   }
-  if (reduglbtab[7] == 1) {                       /* If only one input stream */
-    if (reduglbtab[4] != 0) {
-      errorPrint ("dgraphLoad: cannot load distributed graph from single processor");
-      return     (1);
-    }
-    return (dgraphLoadCent (grafptr, stream, baseval, flagval, reduglbtab[8])); /* Distribute centralized graph from known root */
-  }
-  else if (reduglbtab[7] == grafptr->procglbnbr) { /* If as many input streams as processors */
-    if (versval == 2)                             /* If distributed graph format             */
+
+  if (reduglbtab[4] == 2) {                       /* If distributed graph format             */
+    if (reduglbtab[7] == grafptr->procglbnbr)     /* If as many input streams as processors  */
       return (dgraphLoadDist (grafptr, stream, baseval, flagval)); /* Read distributed graph */
-    else
+  }
+  else {                                          /* If centralized graph format */
+    if (reduglbtab[7] == 1)                       /* If only one reader stream   */
+      return (dgraphLoadCent (grafptr, stream, baseval, flagval, reduglbtab[8])); /* Distribute centralized graph from known root */
+    else if (reduglbtab[7] == grafptr->procglbnbr)
       return (dgraphLoadMulti (grafptr, stream, baseval, flagval)); /* Read multi-centralized graph */
   }
 
@@ -172,21 +172,21 @@ const int                   protnum)              /* Root process number
   Gnum                vertglbnbr;
   Gnum                vertglbmax;
   Gnum                vertlocnbr;
-  Gnum * restrict     vertloctax;
-  Gnum * restrict     vertlocptr;
+  Gnum *              vertloctax;                 /* [norestrict:async] */
+  Gnum *              vertlocptr;
   Gnum * restrict     vertredtax;
   Gnum                velolocnbr;
   Gnum                velolocsum;
-  Gnum * restrict     veloloctax;
+  Gnum *              veloloctax;
   Gnum * restrict     veloredtax;
   Gnum                vlbllocnbr;
-  Gnum * restrict     vlblloctax;
+  Gnum *              vlblloctax;
   Gnum * restrict     vlblredtax;
   Gnum                edgelocnbr;
-  Gnum * restrict     edgeloctax;
+  Gnum *              edgeloctax;
   Gnum                edgeredmnd;
   Gnum * restrict     edgeredtax;
-  Gnum * restrict     edloloctax;
+  Gnum *              edloloctax;
   Gnum * restrict     edloredtax;
   Gnum                degrglbmax;
   Gnum                baseadj;
@@ -620,7 +620,7 @@ const int                   protnum)              /* Root process number
   o = dgraphBuild2 (grafptr, baseval,             /* Build distributed graph */
                     vertlocnbr, vertlocnbr, vertloctax, vertloctax + 1, veloloctax, velolocsum, NULL, vlblloctax,
                     edgelocnbr, edgelocnbr, edgeloctax, NULL, edloloctax, degrglbmax); /* Non-readers will have degrglbmax set to 0 */
-  grafptr->flagval = DGRAPHFREETABS | DGRAPHVERTGROUP | DGRAPHEDGEGROUP;
+  grafptr->flagval |= DGRAPHFREETABS | DGRAPHVERTGROUP | DGRAPHEDGEGROUP;
 
   return (o);
 }
@@ -646,7 +646,7 @@ const DgraphFlag            flagval)              /* Graph loading flags
   Gnum                vertlocnnd;
   Gnum                vertlocnum;
   Gnum * restrict     vertloctax;
-  Gnum * restrict     vertlocptr;
+  Gnum *              vertlocptr;
   Gnum                velolocnbr;
   Gnum                velolocsum;
   Gnum * restrict     veloloctax;
@@ -757,7 +757,7 @@ const DgraphFlag            flagval)              /* Graph loading flags
     vertloctax  =
     vertlocptr -= baseval;
     vertlocptr += vertlocnbr + 1;
-    if (proptab[2] != 0) {
+    if ((proptab[2] != 0) && ((flagval & GRAPHIONOLOADVERT) == 0)) {
       veloloctax  = vertlocptr;
       vertlocptr += vertlocnbr;
     }
@@ -773,7 +773,7 @@ const DgraphFlag            flagval)              /* Graph loading flags
     }
     else {
       edgeloctax -= baseval;
-      edloloctax  = (edlolocnbr != 0) ? (edgeloctax + edgelocnbr) : NULL;
+      edloloctax  = ((proptab[1] != 0) && ((flagval & GRAPHIONOLOADEDGE) == 0)) ? (edgeloctax + edgelocnbr) : NULL;
     }
   }
 
@@ -876,7 +876,7 @@ const DgraphFlag            flagval)              /* Graph loading flags
   o = dgraphBuild2 (grafptr, baseval,             /* Build distributed graph */
                     vertlocnbr, vertlocnbr, vertloctax, vertloctax + 1, veloloctax, velolocsum, NULL, vlblloctax,
                     edgelocnbr, edgelocnbr, edgeloctax, NULL, edloloctax, degrlocmax);
-  grafptr->flagval = DGRAPHFREETABS | DGRAPHVERTGROUP | DGRAPHEDGEGROUP;
+  grafptr->flagval |= DGRAPHFREETABS | DGRAPHVERTGROUP | DGRAPHEDGEGROUP;
 
   return (o);
 }
