@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2009 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2009,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,7 +41,7 @@
 /**   DATES      : # Version 4.0  : from : 28 sep 2002     **/
 /**                                 to     04 jan 2005     **/
 /**                # Version 5.1  : from : 01 oct 2009     **/
-/**                                 to   : 01 oct 2009     **/
+/**                                 to   : 04 nov 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -52,7 +52,7 @@
 /*+ This structure holds the method parameters. +*/
 
 typedef struct HmeshOrderBlParam_ {
-  Strat * restrict          strat;                /*+ Ordering strategy    +*/
+  Strat *                   strat;                /*+ Ordering strategy    +*/
   INT                       cblkmin;              /*+ Block splitting size +*/
 } HmeshOrderBlParam;
 
