@@ -42,7 +42,7 @@
 /**   DATES      : # Version 5.0  : from : 25 apr 2006     **/
 /**                                 to     11 nov 2008     **/
 /**                # Version 5.1  : from : 29 mar 2010     **/
-/**                                 to     29 mar 2010     **/
+/**                                 to     14 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -69,29 +69,6 @@
 /*                                  */
 /************************************/
 
-/*+ This routine parses the given
-*** distributed graph ordering strategy.
-*** It returns:
-*** - 0   : if string successfully scanned.
-*** - !0  : on error.
-+*/
-
-int
-SCOTCH_stratDgraphOrder (
-SCOTCH_Strat * const        stratptr,
-const char * const          string)
-{
-  if (*((Strat **) stratptr) != NULL)
-    stratExit (*((Strat **) stratptr));
-
-  if ((*((Strat **) stratptr) = stratInit (&hdgraphorderststratab, string)) == NULL) {
-    errorPrint ("SCOTCH_stratDgraphOrder: error in ordering strategy");
-    return     (1);
-  }
-
-  return (0);
-}
-
 /*+ This routine initializes an API ordering
 *** with respect to the given source graph
 *** and the locations of output parameters.
@@ -159,7 +136,7 @@ FILE * const                    stream)           /*+ Output stream    +*/
 
 int
 SCOTCH_dgraphOrderCompute (
-const SCOTCH_Dgraph * const grafptr,              /*+ Graph to order      +*/
+SCOTCH_Dgraph * const       grafptr,              /*+ Graph to order      +*/
 SCOTCH_Dordering * const    ordeptr,              /*+ Ordering to compute +*/
 SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy   +*/
 {
@@ -177,7 +154,7 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy   +*/
 
 int
 SCOTCH_dgraphOrderComputeList (
-const SCOTCH_Dgraph * const grafptr,              /*+ Graph to order                  +*/
+SCOTCH_Dgraph * const       grafptr,              /*+ Graph to order                  +*/
 SCOTCH_Dordering * const    ordeptr,              /*+ Ordering to compute             +*/
 const SCOTCH_Num            listnbr,              /*+ Number of vertices in list      +*/
 const SCOTCH_Num * const    listtab,              /*+ List of vertex indices to order +*/
@@ -191,16 +168,24 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy
   Gnum * restrict     srclisttab;                 /* Subgraph vertex list         */
   const Strat *       ordstratptr;                /* Pointer to ordering strategy */
 
+  srcgrafptr = (Dgraph *) grafptr;
+
+#ifdef SCOTCH_DEBUG_DGRAPH2
+  if (dgraphCheck (srcgrafptr) != 0) {
+    errorPrint ("SCOTCH_dgraphOrderComputeList: invalid input graph");
+    return     (1);
+  }
+#endif /* SCOTCH_DEBUG_DGRAPH2 */
+
   if (*((Strat **) stratptr) == NULL)             /* Set default ordering strategy if necessary */
-    *((Strat **) stratptr) = stratInit (&hdgraphorderststratab, "n{sep=m{asc=b{width=3,strat=q{strat=f}},low=q{strat=h},vert=100,dvert=10,dlevl=0,proc=1,seq=q{strat=m{type=h,vert=100,low=h{pass=10},asc=b{width=3,bnd=f{bal=0.2},org=h{pass=10}f{bal=0.2}}}}},ole=q{strat=n{sep=/(vert>120)?m{type=h,vert=100,low=h{pass=10},asc=b{width=3,bnd=f{bal=0.2},org=h{pass=10}f{bal=0.2}}};,ole=f{cmin=15,cmax=100000,frat=0.0},ose=g}},ose=s,osq=n{sep=/(vert>120)?m{type=h,vert=100,low=h{pass=10},asc=b{width=3,bnd=f{bal=0.2},org=h{pass=10}f{bal=0.2}}};,ole=f{cmin=15,cmax=100000,frat=0.0},ose=g}}");
+    SCOTCH_stratDgraphOrderBuild (stratptr, SCOTCH_STRATQUALITY, srcgrafptr->procglbnbr, 0.2);
+
   ordstratptr = *((Strat **) stratptr);
   if (ordstratptr->tabl != &hdgraphorderststratab) {
     errorPrint ("SCOTCH_dgraphOrderComputeList: not a distributed ordering strategy");
     return     (1);
   }
 
-  srcgrafptr = (Dgraph *) grafptr;
-
   srcgrafdat.s            = *srcgrafptr;          /* Copy non-halo graph data    */
   srcgrafdat.s.edloloctax = NULL;                 /* Never mind about edge loads */
   srcgrafdat.vhallocnbr   = 0;                    /* No halo on graph            */
@@ -229,3 +214,63 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy
 
   return (0);
 }
+
+/*+ This routine parses the given
+*** distributed graph ordering strategy.
+*** It returns:
+*** - 0   : if string successfully scanned.
+*** - !0  : on error.
++*/
+
+int
+SCOTCH_stratDgraphOrder (
+SCOTCH_Strat * const        stratptr,
+const char * const          string)
+{
+  if (*((Strat **) stratptr) != NULL)
+    stratExit (*((Strat **) stratptr));
+
+  if ((*((Strat **) stratptr) = stratInit (&hdgraphorderststratab, string)) == NULL) {
+    errorPrint ("SCOTCH_stratDgraphOrder: error in ordering strategy");
+    return     (1);
+  }
+
+  return (0);
+}
+
+/*+ This routine provides predefined
+*** ordering strategies.
+*** It returns:
+*** - 0   : if string successfully initialized.
+*** - !0  : on error.
++*/
+
+int
+SCOTCH_stratDgraphOrderBuild (
+SCOTCH_Strat * const        stratptr,             /*+ Strategy to create              +*/
+const SCOTCH_Num            flagval,              /*+ Desired characteristics         +*/
+const SCOTCH_Num            procnbr,              /*+ Number of processes for running +*/
+const double                balrat)               /*+ Desired imbalance ratio         +*/
+{
+  char                bufftab[8192];              /* Should be enough */
+  char                bbaltab[32];
+  char                verttab[32];
+  Gnum                vertnbr;
+
+  vertnbr = MAX (2000 * procnbr, 10000);
+  vertnbr = MIN (vertnbr, 1000000);
+  sprintf (verttab, GNUMSTRING, vertnbr);
+
+  strcpy (bufftab, "n{sep=m{vert=<VERT>,asc=b{width=3,strat=q{strat=f}},low=q{strat=h},vert=100,dvert=10,dlevl=0,proc=1,seq=q{strat=m{type=h,vert=100,low=h{pass=10},asc=b{width=3,bnd=f{bal=<BBAL>},org=h{pass=10}f{bal=<BBAL>}}}}},ole=q{strat=n{sep=/(vert>120)?m{type=h,vert=100,low=h{pass=10},asc=b{width=3,bnd=f{bal=<BBAL>},org=h{pass=10}f{bal=<BBAL>}}};,ole=f{cmin=15,cmax=100000,frat=0.0},ose=g}},ose=s,osq=n{sep=/(vert>120)?m{type=h,vert=100,low=h{pass=10},asc=b{width=3,bnd=f{bal=<BBAL>},org=h{pass=10}f{bal=<BBAL>}}};,ole=f{cmin=15,cmax=100000,frat=0.0},ose=g}}");
+
+  sprintf (bbaltab, "%lf", balrat);
+  stringSubst (bufftab, "<BBAL>", bbaltab);
+  stringSubst (bufftab, "<VERT>", verttab);
+
+  if (SCOTCH_stratDgraphOrder (stratptr, bufftab) != 0) {
+    errorPrint ("SCOTCH_stratDgraphOrderBuild: error in parallel ordering strategy");
+    return     (1);
+  }
+
+  return (0);
+}
