@@ -42,7 +42,7 @@
 /**   DATES      : # Version 5.0  : from : 16 feb 2007     **/
 /**                                 to     31 may 2008     **/
 /**                # Version 5.1  : from : 27 mar 2010     **/
-/**                                 to     29 mar 2010     **/
+/**                                 to     25 jul 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -63,28 +63,6 @@
 /*                                    */
 /**************************************/
 
-FORTRAN (                                           \
-SCOTCHFSTRATDGRAPHORDER, scotchfstratdgraphorder, ( \
-SCOTCH_Strat * const        stratptr,               \
-const char * const          string,                 \
-int * const                 revaptr,                \
-const int                   strnbr),                \
-(stratptr, string, revaptr, strnbr))
-{
-  char * restrict     strtab;                     /* Pointer to null-terminated string */
-
-  if ((strtab = (char *) memAlloc (strnbr + 1)) == NULL) { /* Allocate temporary space */
-    errorPrint ("SCOTCHFSTRATDGRAPHORDER: out of memory (1)");
-    *revaptr = 1;
-  }
-  memCpy (strtab, string, strnbr);                /* Copy string contents */
-  strtab[strnbr] = '\0';                          /* Terminate string     */
-
-  *revaptr = SCOTCH_stratDgraphOrder (stratptr, strtab); /* Call original routine */
-
-  memFree (strtab);                               /* Prevent compiler warnings */
-}
-
 /*
 **
 */
@@ -158,7 +136,7 @@ int * const                     revaptr),         \
 
 FORTRAN (                                               \
 SCOTCHFDGRAPHORDERCOMPUTE, scotchfdgraphordercompute, ( \
-const SCOTCH_Dgraph * const grafptr,                    \
+SCOTCH_Dgraph * const       grafptr,                    \
 SCOTCH_Dordering * const    ordeptr,                    \
 SCOTCH_Strat * const        stratptr,                   \
 int * const                 revaptr),                   \
@@ -173,7 +151,7 @@ int * const                 revaptr),                   \
 
 FORTRAN (                                                       \
 SCOTCHFDGRAPHORDERCOMPUTELIST, scotchfdgraphordercomputelist, ( \
-const SCOTCH_Dgraph * const grafptr,                            \
+SCOTCH_Dgraph * const       grafptr,                            \
 SCOTCH_Dordering * const    ordeptr,                            \
 const SCOTCH_Num *          listptr,                            \
 const SCOTCH_Num * const    listtab,                            \
@@ -183,3 +161,45 @@ int * const                 revaptr),                           \
 {
   *revaptr = SCOTCH_dgraphOrderComputeList (grafptr, ordeptr, *listptr, listtab, stratptr);
 }
+
+/*
+**
+*/
+
+FORTRAN (                                           \
+SCOTCHFSTRATDGRAPHORDER, scotchfstratdgraphorder, ( \
+SCOTCH_Strat * const        stratptr,               \
+const char * const          string,                 \
+int * const                 revaptr,                \
+const int                   strnbr),                \
+(stratptr, string, revaptr, strnbr))
+{
+  char * restrict     strtab;                     /* Pointer to null-terminated string */
+
+  if ((strtab = (char *) memAlloc (strnbr + 1)) == NULL) { /* Allocate temporary space */
+    errorPrint ("SCOTCHFSTRATDGRAPHORDER: out of memory (1)");
+    *revaptr = 1;
+  }
+  memCpy (strtab, string, strnbr);                /* Copy string contents */
+  strtab[strnbr] = '\0';                          /* Terminate string     */
+
+  *revaptr = SCOTCH_stratDgraphOrder (stratptr, strtab); /* Call original routine */
+
+  memFree (strtab);                               /* Prevent compiler warnings */
+}
+
+/*
+**
+*/
+
+FORTRAN (                                                     \
+SCOTCHFSTRATDGRAPHORDERBUILD, scotchfstratdgraphorderbuild, ( \
+SCOTCH_Strat * const        stratptr,                         \
+const SCOTCH_Num * const    flagval,                          \
+const SCOTCH_Num * const    procnbr,                          \
+const double * const        balrat,                           \
+int * const                 revaptr),                         \
+(stratptr, flagval, procnbr, balrat, revaptr))
+{
+  *revaptr = SCOTCH_stratDgraphOrderBuild (stratptr, *flagval, *procnbr, *balrat);
+}
