@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -31,7 +31,7 @@
 */
 /************************************************************/
 /**                                                        **/
-/**   NAME       : library_graph_map-view.c                **/
+/**   NAME       : library_graph_map_view.c                **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
 /**                                                        **/
@@ -48,6 +48,8 @@
 /**                                 to     30 nov 2006     **/
 /**                # Version 5.0  : from : 04 feb 2007     **/
 /**                                 to     03 apr 2008     **/
+/**                # Version 5.1  : from : 27 jul 2008     **/
+/**                                 to     11 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -92,8 +94,8 @@ FILE * const                  stream)
   const Graph * restrict    grafptr;
   const Mapping * restrict  mappptr;
   Anum * restrict           parttax;              /* Part array                                   */
-  MappingSort * restrict    domtab;               /* Pointer to domain sort array                 */
-  ArchDom                   domfrst;              /* Largest domain in architecture               */
+  MappingSort * restrict    domntab;              /* Pointer to domain sort array                 */
+  ArchDom                   domnfrst;             /* Largest domain in architecture               */
   Anum                      tgtnbr;               /* Number of processors in target topology      */
   Anum                      mapnbr;               /* Number of processors effectively used        */
   Anum                      mapnum;
@@ -103,17 +105,14 @@ FILE * const                  stream)
   Gnum                      mapsum;               /* (Partial) sum of vertex loads                */
   double                    mapdlt;
   double                    mapmmy;               /* Maximum / average ratio                      */
-  Anum *                    labltab;
-  Anum *                    labltax;
-  Anum * restrict           ngbtab;               /* Table storing neighbors of current subdomain */
-  Anum                      ngbnbr;
-  Anum                      ngbsum;
-  Anum                      ngbnum;
-  Anum                      ngbmin;
-  Anum                      ngbmax;
+  Anum * restrict           nghbtab;              /* Table storing neighbors of current subdomain */
+  Anum                      nghbnbr;
+  Anum                      nghbmin;
+  Anum                      nghbmax;
+  Anum                      nghbsum;
   Gnum                      vertnum;
-  Gnum                      vertload;
-  Gnum                      edgeload;
+  Gnum                      veloval;
+  Gnum                      edloval;
   Gnum                      commdist[256];        /* Array of load distribution */
   Gnum                      commload;             /* Total edge load (edge sum) */
   Gnum                      commdilat;            /* Total edge dilation        */
@@ -123,7 +122,12 @@ FILE * const                  stream)
   Gnum                      diammin;
   Gnum                      diammax;
   Gnum                      diamsum;
-  Anum                      i;
+
+  const Gnum * restrict const verttax = ((Graph *) libgrafptr)->verttax;
+  const Gnum * restrict const vendtax = ((Graph *) libgrafptr)->vendtax;
+  const Gnum * restrict const velotax = ((Graph *) libgrafptr)->velotax;
+  const Gnum * restrict const edgetax = ((Graph *) libgrafptr)->edgetax;
+  const Gnum * restrict const edlotax = ((Graph *) libgrafptr)->edlotax;
 
   grafptr = (Graph *) libgrafptr;
   mappptr = &((LibMapping *) libmappptr)->m;
@@ -133,40 +137,39 @@ FILE * const                  stream)
     return (0);
 
   if (memAllocGroup ((void **) (void *)
-                     &domtab,  (size_t) ((grafptr->vertnbr + 1) * sizeof (MappingSort)),
-                     &ngbtab,  (size_t) ((grafptr->vertnbr + 2) * sizeof (Anum)),
+                     &domntab, (size_t) ((grafptr->vertnbr + 1) * sizeof (MappingSort)),
                      &parttax, (size_t) (grafptr->vertnbr       * sizeof (Anum)),
-                     &labltab, (size_t) (grafptr->vertnbr       * sizeof (Anum)), NULL) == NULL) {
-    errorPrint ("mapView: out of memory");
+                     &nghbtab, (size_t) ((grafptr->vertnbr + 2) * sizeof (Anum)), NULL) == NULL) {
+    errorPrint ("SCOTCH_graphMapView: out of memory");
     return     (1);
   }
 
   memSet (parttax, ~0, grafptr->vertnbr * sizeof (Anum));
-  parttax -= grafptr->baseval;
 
   for (vertnum = 0; vertnum < grafptr->vertnbr; vertnum ++) {
-    labltab[vertnum]     =
-    domtab[vertnum].labl = archDomNum (&mappptr->archdat, mapDomain (mappptr, vertnum + grafptr->baseval));
-    domtab[vertnum].peri = vertnum + grafptr->baseval; /* Build inverse permutation */
+    parttax[vertnum]      =
+    domntab[vertnum].labl = archDomNum (&mappptr->archdat, mapDomain (mappptr, vertnum + grafptr->baseval));
+    domntab[vertnum].peri = vertnum + grafptr->baseval; /* Build inverse permutation */
   }
-  domtab[grafptr->vertnbr].labl = ARCHDOMNOTTERM; /* TRICK: avoid testing (i+1)    */
-  domtab[grafptr->vertnbr].peri = ~0;             /* Prevent Valgrind from yelling */
+  domntab[grafptr->vertnbr].labl = ARCHDOMNOTTERM; /* TRICK: avoid testing (i+1)   */
+  domntab[grafptr->vertnbr].peri = ~0;            /* Prevent Valgrind from yelling */
+  parttax -= grafptr->baseval;                    /* From now on, base part array  */
 
-  intSort2asc2 (domtab, grafptr->vertnbr);        /* Sort domain label array by increasing target labels */
+  intSort2asc2 (domntab, grafptr->vertnbr);       /* Sort domain label array by increasing target labels */
 
-  archDomFrst (&mappptr->archdat, &domfrst);      /* Get architecture domain   */
-  tgtnbr = archDomSize (&mappptr->archdat, &domfrst); /* Get architecture size */
+  archDomFrst (&mappptr->archdat, &domnfrst);     /* Get architecture domain    */
+  tgtnbr = archDomSize (&mappptr->archdat, &domnfrst); /* Get architecture size */
 
-  mapsum   = 0;
-  mapnbr   = 0;
-  vertload = 1;                                   /* Assume unweighted vertices */
-  for (vertnum = 0; domtab[vertnum].labl != ARCHDOMNOTTERM; vertnum ++) {
-    parttax[domtab[vertnum].peri] = mapnbr;       /* Build map of partition parts starting from 0 */
-    if (domtab[vertnum].labl != domtab[vertnum + 1].labl) /* TRICK: if new (or end) domain label  */
+  mapsum  = 0;
+  mapnbr  = 0;
+  veloval = 1;                                    /* Assume unweighted vertices */
+  for (vertnum = 0; domntab[vertnum].labl != ARCHDOMNOTTERM; vertnum ++) {
+    parttax[domntab[vertnum].peri] = mapnbr;      /* Build map of partition parts starting from 0  */
+    if (domntab[vertnum].labl != domntab[vertnum + 1].labl) /* TRICK: if new (or end) domain label */
       mapnbr ++;
-    if (grafptr->velotax != NULL)
-      vertload = grafptr->velotax[domtab[vertnum].peri];
-    mapsum += vertload;
+    if (velotax != NULL)
+      veloval = velotax[domntab[vertnum].peri];
+    mapsum += veloval;
   }
   mapavg = (mapnbr == 0) ? 0.0L : (double) mapsum / (double) mapnbr;
 
@@ -174,12 +177,12 @@ FILE * const                  stream)
   mapmin = GNUMMAX;
   mapmax = 0;
   mapdlt = 0.0L;
-  for (vertnum = 0; domtab[vertnum].labl != ARCHDOMNOTTERM; vertnum ++) {
-    if (grafptr->velotax != NULL)
-      vertload = grafptr->velotax[domtab[vertnum].peri];
-    mapsum += vertload;
+  for (vertnum = 0; domntab[vertnum].labl != ARCHDOMNOTTERM; vertnum ++) {
+    if (velotax != NULL)
+      veloval = velotax[domntab[vertnum].peri];
+    mapsum += veloval;
 
-    if (domtab[vertnum].labl != domtab[vertnum + 1].labl) { /* TRICK: if new (or end) domain label */
+    if (domntab[vertnum].labl != domntab[vertnum + 1].labl) { /* TRICK: if new (or end) domain label */
       if (mapsum < mapmin)
         mapmin = mapsum;
       if (mapsum > mapmax)
@@ -193,101 +196,128 @@ FILE * const                  stream)
 
   if (mapnbr > tgtnbr) {                          /* If more subdomains than architecture size */
 #ifdef SCOTCH_DEBUG_MAP2
-    if (strncmp (archName (&mappptr->archdat), "var", 3) != 0) { /* If not a variable-sized architecture */
-      errorPrint ("mapView: invalid mapping");
-      memFree    (domtab);                        /* Free group leader */
+    if (! archVar (&mappptr->archdat)) {          /* If not a variable-sized architecture */
+      errorPrint ("SCOTCH_graphMapView: invalid mapping");
+      memFree    (domntab);                       /* Free group leader */
       return     (1);
     }
 #endif /* SCOTCH_DEBUG_MAP2 */
     tgtnbr = mapnbr;                              /* Assume it is a variable-sized architecture */
   }
 
-  fprintf (stream, "M\tProcessors %ld/%ld (%g)\n",
-           (long) mapnbr, (long) tgtnbr,
+  fprintf (stream, "M\tProcessors " GNUMSTRING "/" GNUMSTRING " (%g)\n",
+           (Gnum) mapnbr,
+           (Gnum) tgtnbr,
            (double) mapnbr / (double) tgtnbr);
-  fprintf (stream, "M\tTarget min=%ld\tmax=%ld\tavg=%g\tdlt=%g\tmaxavg=%g\n",
-           (long) mapmin,
-           (long) mapmax,
+  fprintf (stream, "M\tTarget min=" GNUMSTRING "\tmax=" GNUMSTRING "\tavg=%g\tdlt=%g\tmaxavg=%g\n",
+           (Gnum) mapmin,
+           (Gnum) mapmax,
            mapavg,
            mapdlt,
            mapmmy);
 
-  labltax = labltab - grafptr->baseval;
-
-  ngbnbr = 0;
-  ngbmin = ANUMMAX;
-  ngbmax = 0;
-  ngbsum = 0;
-  ngbnum = 0;
-  ngbtab[0] = ANUMMAX;
-  for (vertnum = 0; domtab[vertnum].labl != ARCHDOMNOTTERM; vertnum ++) {
+  nghbnbr = 0;
+  nghbmin = ANUMMAX;
+  nghbmax = 0;
+  nghbsum = 0;
+  nghbnbr = 0;
+  nghbtab[0] = -2;
+  for (vertnum = 0; domntab[vertnum].labl != ARCHDOMNOTTERM; vertnum ++) {
     Gnum                edgenum;
+    Gnum                edgennd;
+    Anum                partnum;
 
-    for (edgenum = grafptr->verttax[domtab[vertnum].peri];
-         edgenum < grafptr->vendtax[domtab[vertnum].peri];
-         edgenum ++) {
-      if ((labltax[grafptr->edgetax[edgenum]] != labltax[domtab[vertnum].peri]) && /* If edge is not internal */
-          (labltax[grafptr->edgetax[edgenum]] != ngbtab[ngbnum])) /* And neighbor has not just been found     */
-        ngbtab[++ ngbnum] = labltax[grafptr->edgetax[edgenum]];
-    }
-    if (domtab[vertnum].labl != domtab[vertnum + 1].labl) { /* TRICK: if new (or end) domain label  */
-      intSort1asc1 (ngbtab, ngbnum + 1);          /* Sort neighbor label array by increasing labels */
-      for (i = 0, ngbnbr = 0; ngbtab[i] != ANUMMAX; i ++) {
-        if (ngbtab[i] != ngbtab[i + 1])
-          ngbnbr ++;
+    partnum = parttax[domntab[vertnum].peri];
+    for (edgenum = verttax[domntab[vertnum].peri],
+         edgennd = vendtax[domntab[vertnum].peri];
+         edgenum < edgennd; edgenum ++) {
+      Anum                partend;
+
+      partend = parttax[edgetax[edgenum]];
+      if ((partend != partnum) &&                 /* If edge is not internal                                      */
+          (partend != nghbtab[nghbnbr])) {        /* And neighbor is not sole neighbor or has not just been found */
+        Anum                partmin;
+        Anum                partmax;
+
+        partmin = 0;
+        partmax = nghbnbr;
+        while ((partmax - partmin) > 1) {
+          Anum                partmed;
+
+          partmed = (partmax + partmin) >> 1;
+          if (nghbtab[partmed] > partend)
+            partmax = partmed;
+          else
+            partmin = partmed;
+        }
+        if (nghbtab[partmin] == partend)          /* If neighboring part found, skip to next neighbor */
+          continue;
+
+#ifdef SCOTCH_DEBUG_MAP2
+        if (nghbnbr >= (grafptr->vertnbr + 1)) {
+          errorPrint ("SCOTCH_graphMapView: internal error");
+          return (1);
+        }
+#endif /* SCOTCH_DEBUG_MAP2 */
+
+        nghbnbr ++;
+        for (partmax = nghbnbr; partmax > (partmin + 1); partmax --)
+          nghbtab[partmax] = nghbtab[partmax - 1];
+        nghbtab[partmin + 1] = partend;           /* Add new neighbor part in the right place */
       }
-      if (ngbnbr < ngbmin)
-        ngbmin = ngbnbr;
-      if (ngbnbr > ngbmax)
-        ngbmax = ngbnbr;
-      ngbsum += ngbnbr;
+    }
+    if (domntab[vertnum].labl != domntab[vertnum + 1].labl) { /* TRICK: if new (or end) domain label */
+      if (nghbnbr < nghbmin)
+        nghbmin = nghbnbr;
+      if (nghbnbr > nghbmax)
+        nghbmax = nghbnbr;
+      nghbsum += nghbnbr;
 
-      ngbnum = 0;
-      ngbtab[0] = ANUMMAX;
+      nghbnbr = 0;
     }
   }
 
-  fprintf (stream, "M\tNeighbors min=%ld\tmax=%ld\tsum=%ld\n",
-           (long) ngbmin,
-           (long) ngbmax,
-           (long) ngbsum);
+  fprintf (stream, "M\tNeighbors min=" GNUMSTRING "\tmax=" GNUMSTRING "\tsum=" GNUMSTRING "\n",
+           (Gnum) nghbmin,
+           (Gnum) nghbmax,
+           (Gnum) nghbsum);
 
   memset (commdist, 0, 256 * sizeof (Gnum));      /* Initialize the data */
   commload  =
   commdilat =
   commexpan = 0;
 
-  edgeload = 1;
-  for (vertnum = 0; vertnum < grafptr->vertnbr; vertnum ++) {
+  edloval = 1;
+  for (vertnum = grafptr->baseval; vertnum < grafptr->vertnnd; vertnum ++) {
     Gnum                edgenum;
 
-    if (labltab[vertnum] == ARCHDOMNOTTERM)       /* Skip unmapped vertices */
+    if (parttax[vertnum] == ~0)                   /* Skip unmapped vertices */
       continue;
-    for (edgenum = grafptr->verttax[vertnum + grafptr->baseval];
-         edgenum < grafptr->vendtax[vertnum + grafptr->baseval]; edgenum ++) {
-      if (labltax[grafptr->edgetax[edgenum]] == ARCHDOMNOTTERM)
+    for (edgenum = verttax[vertnum];
+         edgenum < vendtax[vertnum]; edgenum ++) {
+      if (parttax[edgetax[edgenum]] == ~0)
         continue;
-      distval = archDomDist (&mappptr->archdat, mapDomain (mappptr, vertnum + grafptr->baseval), mapDomain (mappptr, grafptr->edgetax[edgenum]));
-      if (grafptr->edlotax != NULL)              /* Get edge weight if any */
-        edgeload = grafptr->edlotax[edgenum];
-      commdist[(distval > 255) ? 255 : distval] += edgeload;
-      commload  += edgeload;
+      distval = archDomDist (&mappptr->archdat, mapDomain (mappptr, vertnum), mapDomain (mappptr, edgetax[edgenum]));
+      if (edlotax != NULL)                        /* Get edge weight if any */
+        edloval = edlotax[edgenum];
+      commdist[(distval > 255) ? 255 : distval] += edloval;
+      commload  += edloval;
       commdilat += distval;
-      commexpan += distval * edgeload;
+      commexpan += distval * edloval;
     }
   }
 
-  fprintf (stream, "M\tCommDilat=%f\t(%ld)\n",    /* Print expansion parameters */
+  fprintf (stream, "M\tCommDilat=%f\t(" GNUMSTRING ")\n", /* Print expansion parameters */
            (double) commdilat / grafptr->edgenbr,
-           (long) (commdilat / 2));
-  fprintf (stream, "M\tCommExpan=%f\t(%ld)\n",
+           (Gnum) (commdilat / 2));
+  fprintf (stream, "M\tCommExpan=%f\t(" GNUMSTRING ")\n",
            ((commload == 0) ? (double) 0.0L
                             : (double) commexpan / (double) commload),
-           (long) (commexpan / 2));
-  fprintf (stream, "M\tCommCutSz=%f\t(%ld)\n",
+           (Gnum) (commexpan / 2));
+  fprintf (stream, "M\tCommCutSz=%f\t(" GNUMSTRING ")\n",
            ((commload == 0) ? (double) 0.0L
                             : (double) (commload - commdist[0]) / (double) commload),
-           (long) ((commload - commdist[0]) / 2));
+           (Gnum) ((commload - commdist[0]) / 2));
   fprintf (stream, "M\tCommDelta=%f\n",
            (((double) commload  * (double) commdilat) == 0.0L)
            ? (double) 0.0L
@@ -298,8 +328,8 @@ FILE * const                  stream)
     if (commdist[distmax] != 0)
       break;
   for (distval = 0; distval <= distmax; distval ++) /* Print distance histogram */
-    fprintf (stream, "M\tCommLoad[%ld]=%f\n",
-             (long) distval, (double) commdist[distval] / (double) commload);
+    fprintf (stream, "M\tCommLoad[" ANUMSTRING "]=%f\n",
+             (Anum) distval, (double) commdist[distval] / (double) commload);
 
   diammin = GNUMMAX;
   diammax = 0;
@@ -314,16 +344,18 @@ FILE * const                  stream)
     if (diamval > diammax)
       diammax = diamval;
   }
-  fprintf (stream, "M\tPartDiam\tmin=%ld\tmax=%ld\tavg=%lf\n",
-           (long) diammin, (long) diammax, (double) diamsum / (double) mapnbr);
+  fprintf (stream, "M\tPartDiam\tmin=" GNUMSTRING "\tmax=" GNUMSTRING "\tavg=%lf\n",
+           (Gnum) diammin,
+           (Gnum) diammax,
+           (double) diamsum / (double) mapnbr);
 
-  memFree (domtab);                               /* Free group leader */
+  memFree (domntab);                              /* Free group leader */
 
   return (0);
 }
 
 /*+ This routine computes the pseudo-diameter of
-*** tthe given part.    
+*** the given part.    
 *** It returns:
 *** - 0   : on success.
 *** - !0  : on error.
@@ -413,5 +445,7 @@ const Anum                  partval)              /*+ Part value +*/
     }
   }
 
+  memFree (queudat.qtab);                         /* Free group leader */
+
   return (diamdist);
 }
