@@ -47,7 +47,7 @@
 !*                # Version 5.0  : from : 26 apr 2006     **
 !*                                 to     26 apr 2006     **
 !*                # Version 5.1  : from : 26 mar 2009     **
-!*                                 to     24 jul 2010     **
+!*                                 to     12 feb 2011     **
 !*                                                        **
 !***********************************************************
 
@@ -59,11 +59,13 @@
         INTEGER SCOTCH_STRATBALANCE
         INTEGER SCOTCH_STRATSCALABILITY
         INTEGER SCOTCH_STRATSAFETY
+        INTEGER SCOTCH_STRATCLUSTER
         PARAMETER (SCOTCH_STRATQUALITY     = 1)
         PARAMETER (SCOTCH_STRATSPEED       = 2)
         PARAMETER (SCOTCH_STRATBALANCE     = 4)
         PARAMETER (SCOTCH_STRATSAFETY      = 8)
         PARAMETER (SCOTCH_STRATSCALABILITY = 16)
+        PARAMETER (SCOTCH_STRATCLUSTER     = 32)
 
 !* Size definitions for the SCOTCH opaque
 !* structures. These structures must be
