@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -49,6 +49,8 @@
 /**                                 to     02 feb 2004     **/
 /**                # Version 5.0  : from : 20 feb 2008     **/
 /**                                 to     20 feb 2008     **/
+/**                # Version 5.1  : from : 22 oct 2008     **/
+/**                                 to     11 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -118,6 +120,9 @@ Strat * const               strat)
   unsigned int      i;
   int               o;
 
+  if (strat == NULL)                              /* If node does not exist, abort */
+    return (0);
+
   o = 0;                                          /* Assume everything will be all right */
   switch (strat->type) {                          /* Recursively free sub-strategies     */
     case STRATNODECONCAT :
@@ -141,9 +146,9 @@ Strat * const               strat)
     case STRATNODEMETHOD :                        /* Method strategy node       */
       paratab = strat->tabl->paratab;             /* Free the method parameters */
       for (i = 0; paratab[i].name != NULL; i ++) {
-        if ((paratab[i].meth == strat->data.method.meth) && /* For all parameters of that method  */
-            (paratab[i].type == STRATPARAMSTRAT)) { /* Which are strategy parameters              */
-          paraofft = (byte*) &strat->data.method.data + /* Compute parameter offset within method */
+        if ((paratab[i].meth == strat->data.method.meth) && /* For all parameters of that method   */
+            (paratab[i].type == STRATPARAMSTRAT)) { /* Which are strategy parameters               */
+          paraofft = (byte *) &strat->data.method.data + /* Compute parameter offset within method */
                       (paratab[i].dataofft -
                        paratab[i].database);
           o |= stratExit (*((Strat **) paraofft)); /* Perform recursion */
@@ -234,7 +239,7 @@ FILE * const                stream)
                             ((char *) paratab[i].datasltr)[*((unsigned int *) paraofft)]) == EOF);
               break;
             case STRATPARAMINT :                  /* Integer value */
-              o = (fprintf (stream, "%ld", (long) *((INT *) paraofft)) == EOF);
+              o = (fprintf (stream, INTSTRING, *((INT *) paraofft)) == EOF);
               break;
             case STRATPARAMDOUBLE :               /* Double value */
               o = (fprintf (stream, "%g", *((double *) paraofft)) == EOF);
@@ -357,7 +362,7 @@ const void * restrict const       data)           /*+ Pointer to data structure
       o |= stratTestEvalCast (&val[0], &val[1]);
       if (o != 0)
         break;
-      sign = 0;                                   /* In case of error */
+      sign = STRATTESTNBR;                        /* In case of error */
       switch (val[0].typenode) {
         case STRATPARAMDOUBLE :
           sign = (val[0].data.val.valdbl < val[1].data.val.valdbl) ? STRATTESTLT : ((val[0].data.val.valdbl > val[1].data.val.valdbl) ? STRATTESTGT : STRATTESTEQ);
@@ -602,7 +607,7 @@ FILE * const                stream)
           o = (fprintf (stream, "%lf", test->data.val.valdbl) == EOF);
           break;
         case STRATPARAMINT :
-          o = (fprintf (stream, "%ld", (long) test->data.val.valint) == EOF);
+          o = (fprintf (stream, INTSTRING, (INT) test->data.val.valint) == EOF);
           break;
 #ifdef SCOTCH_DEBUG_PARSER2
         default :
