@@ -1,4 +1,4 @@
-/* Copyright 2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2007-2009 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,7 +41,9 @@
 /**                method tables.                          **/
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 16 feb 2006     **/
-/**                                 to     01 mar 2008     **/
+/**                                 to     01 aug 2007     **/
+/**                # Version 5.1  : from : 05 nov 2007     **/
+/**                                 to     26 may 2009     **/
 /**                                                        **/
 /************************************************************/
 
@@ -61,6 +63,7 @@
 #include "dgraph_coarsen.h"
 #include "vdgraph.h"
 #include "vdgraph_separate_bd.h"
+#include "vdgraph_separate_df.h"
 #include "vdgraph_separate_ml.h"
 #include "vdgraph_separate_sq.h"
 #include "vdgraph_separate_st.h"
@@ -77,10 +80,15 @@ static union {
   StratNodeMethodData       padding;
 } vdgraphseparatedefaultbd = { { 3, &stratdummy } };
 
+static union {
+  VdgraphSeparateDfParam    param;
+  StratNodeMethodData       padding;
+} vdgraphseparatedefaultdf = { { 0, 300, 1.0, 0.0, 0.2 } };
+
 static union {
   VdgraphSeparateMlParam    param;
   StratNodeMethodData       padding;
-} vdgraphseparatedefaultml = { { 1000, 100, 0, 0.8L, 1000, &stratdummy, &stratdummy, &stratdummy, 1 } };
+} vdgraphseparatedefaultml = { { 5, 1000, 100, 0, 0.8L, &stratdummy, &stratdummy, &stratdummy, 1 } };
 
 static union {
   VdgraphSeparateSqParam    param;
@@ -90,6 +98,7 @@ static union {
 
 static StratMethodTab       vdgraphseparatestmethtab[] = { /* Distributed graph separation methods array */
                              { VDGRAPHSEPASTMETHBD, "b",  vdgraphSeparateBd, &vdgraphseparatedefaultbd },
+                             { VDGRAPHSEPASTMETHDF, "d",  vdgraphSeparateDf, &vdgraphseparatedefaultdf },
                              { VDGRAPHSEPASTMETHML, "m",  vdgraphSeparateMl, &vdgraphseparatedefaultml },
                              { VDGRAPHSEPASTMETHSQ, "q",  vdgraphSeparateSq, &vdgraphseparatedefaultsq },
                              { VDGRAPHSEPASTMETHZR, "z",  vdgraphSeparateZr, NULL },
@@ -105,6 +114,26 @@ static StratParamTab        vdgraphseparatestparatab[] = { /* Distributed graph
                                 (byte *) &vdgraphseparatedefaultbd.param,
                                 (byte *) &vdgraphseparatedefaultbd.param.strat,
                                 (void *) &vdgraphseparateststratab },
+                              { VDGRAPHSEPASTMETHDF,  STRATPARAMINT,    "part",
+                                (byte *) &vdgraphseparatedefaultdf.param,
+                                (byte *) &vdgraphseparatedefaultdf.param.partval,
+                                NULL },
+                              { VDGRAPHSEPASTMETHDF,  STRATPARAMINT,    "pass",
+                                (byte *) &vdgraphseparatedefaultdf.param,
+                                (byte *) &vdgraphseparatedefaultdf.param.passnbr,
+                                NULL },
+                              { VDGRAPHSEPASTMETHDF,  STRATPARAMDOUBLE, "bal",
+                                (byte *) &vdgraphseparatedefaultdf.param,
+                                (byte *) &vdgraphseparatedefaultdf.param.deltval,
+                                NULL },
+                              { VDGRAPHSEPASTMETHDF,  STRATPARAMDOUBLE, "dif",
+                                (byte *) &vdgraphseparatedefaultdf.param,
+                                (byte *) &vdgraphseparatedefaultdf.param.cdifval,
+                                NULL },
+                              { VDGRAPHSEPASTMETHDF,  STRATPARAMDOUBLE, "rem",
+                                (byte *) &vdgraphseparatedefaultdf.param,
+                                (byte *) &vdgraphseparatedefaultdf.param.cremval,
+                                NULL },
                               { VDGRAPHSEPASTMETHML,  STRATPARAMSTRAT,  "asc",
                                 (byte *) &vdgraphseparatedefaultml.param,
                                 (byte *) &vdgraphseparatedefaultml.param.stratasc,
@@ -117,6 +146,10 @@ static StratParamTab        vdgraphseparatestparatab[] = { /* Distributed graph
                                 (byte *) &vdgraphseparatedefaultml.param,
                                 (byte *) &vdgraphseparatedefaultml.param.stratseq,
                                 (void *) &vdgraphseparateststratab },
+                              { VDGRAPHSEPASTMETHML,  STRATPARAMINT,    "pass",
+                                (byte *) &vdgraphseparatedefaultml.param,
+                                (byte *) &vdgraphseparatedefaultml.param.passnbr,
+                                NULL },
                               { VDGRAPHSEPASTMETHML,  STRATPARAMINT,    "proc",
                                 (byte *) &vdgraphseparatedefaultml.param,
                                 (byte *) &vdgraphseparatedefaultml.param.seqnbr,
@@ -133,10 +166,6 @@ static StratParamTab        vdgraphseparatestparatab[] = { /* Distributed graph
                                 (byte *) &vdgraphseparatedefaultml.param,
                                 (byte *) &vdgraphseparatedefaultml.param.duplvlmax,
                                 NULL },
-                              { VDGRAPHSEPASTMETHML,  STRATPARAMINT,    "reqsize",
-                                (byte *) &vdgraphseparatedefaultml.param,
-                                (byte *) &vdgraphseparatedefaultml.param.reqsize,
-                                NULL },
                               { VDGRAPHSEPASTMETHML,  STRATPARAMDOUBLE, "rat",
                                 (byte *) &vdgraphseparatedefaultml.param,
                                 (byte *) &vdgraphseparatedefaultml.param.coarrat,
