@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2010,2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -42,6 +42,8 @@
 /**                                 to   : 12 may 2006     **/
 /**                # Version 5.0  : from : 23 dec 2007     **/
 /**                                 to   : 16 mar 2008     **/
+/**                # Version 5.1  : from : 01 jul 2010     **/
+/**                                 to   : 14 feb 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -102,7 +104,7 @@ char *                      argv[])
         C_paraNum ++;                             /* One more parameter                               */
         baseval = atoi (argv[i]);                 /* Get the base value                               */
         if ((baseval < 0) || (baseval > 1)) {
-          errorPrint ("main: invalid base value (\"%s\")", argv[i]);
+          errorPrint ("main: invalid base value '%s'", argv[i]);
           return     (1);
         }
         continue;                                 /* Process the other parameters */
@@ -121,12 +123,12 @@ char *                      argv[])
           usagePrint (stdout, C_usageList);
           exit       (0);
         case 'V' :
-          fprintf (stderr, "gbase, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2006 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "gbase, version " SCOTCH_VERSION_STRING "\n");
+          fprintf (stderr, "Copyright 2007,2008,2010,2011 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
-          errorPrint ("main: unprocessed option (\"%s\")", argv[i]);
+          errorPrint ("main: unprocessed option '%s'", argv[i]);
           exit       (1);
       }
     }
