@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -58,7 +58,7 @@
 /**                # Version 5.0  : from : 23 dec 2007     **/
 /**                                 to   : 11 jun 2008     **/
 /**                # Version 5.1  : from : 01 jul 2010     **/
-/**                                 to   : 01 jul 2010     **/
+/**                                 to   : 14 feb 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -173,7 +173,7 @@ char *                      argv[])
             }
           }
           if (C_inpFormatTab[j].code == '\0') {
-            errorPrint ("main: unprocessed option (\"%s\")", argv[i]);
+            errorPrint ("main: unprocessed option '%s'", argv[i]);
             return     (1);
           }
           break;
@@ -187,17 +187,17 @@ char *                      argv[])
             }
           }
           if (C_inpFormatTab[j].code == '\0') {
-            errorPrint ("main: unprocessed option (\"%s\")", argv[i]);
+            errorPrint ("main: unprocessed option '%s'", argv[i]);
             return     (1);
           }
           break;
         case 'V' :
           fprintf (stderr, "gcv, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010,2011 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
-          errorPrint ("main: unprocessed option (\"%s\")", argv[i]);
+          errorPrint ("main: unprocessed option '%s'", argv[i]);
           return     (1);
       }
     }
