@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,7 +43,7 @@
 /**                # Version 5.0  : from : 13 dec 2007     **/
 /**                                 to   : 16 mar 2008     **/
 /**                # Version 5.1  : from : 01 jul 2010     **/
-/**                                 to   : 15 aug 2010     **/
+/**                                 to   : 14 feb 2011     **/
 /**                                                        **/
 /**   NOTES      : # The vertices of the (dX,dY,dZ) mesh   **/
 /**                  are numbered as terminals so that     **/
@@ -118,7 +118,7 @@ char *                      argv[])
     if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
       if (C_paraNum < 3) {                        /* If number of parameters not reached              */
         if ((d[C_paraNum ++] = atoi (argv[i])) < 1) { /* Get the dimension                            */
-          errorPrint ("main: invalid dimension (\"%s\")", argv[i]);
+          errorPrint ("main: invalid dimension '%s'", argv[i]);
           return     (1);
         }
         continue;                                 /* Process the other parameters */
@@ -136,7 +136,7 @@ char *                      argv[])
         case 'b' :
           baseval = (SCOTCH_Num) atol (&argv[i][2]);
           if ((baseval < 0) || (baseval > 1)) {
-            errorPrint ("main: invalid base value (" SCOTCH_NUMSTRING ")", (SCOTCH_Num) baseval);
+            errorPrint ("main: invalid base value '" SCOTCH_NUMSTRING "'", (SCOTCH_Num) baseval);
           }
           break;
         case 'G' :                                /* Output the geometry */
@@ -155,11 +155,11 @@ char *                      argv[])
           break;
         case 'V' :
           fprintf (stderr, "gmk_m3, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010,2011 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
-          errorPrint ("main: unprocessed option (\"%s\")", argv[i]);
+          errorPrint ("main: unprocessed option '%s'", argv[i]);
           return     (1);
       }
     }
