@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2011 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,7 +43,7 @@
 /**                # Version 5.0  : from : 22 jan 2008     **/
 /**                                 to   : 16 mar 2008     **/
 /**                # Version 5.1  : from : 08 sep 2008     **/
-/**                                 to   : 25 jul 2010     **/
+/**                                 to   : 14 feb 2011     **/
 /**                                                        **/
 /************************************************************/
 
@@ -157,7 +157,7 @@ char *                      argv[])
                 straval |= SCOTCH_STRATSAFETY;
                 break;
               default :
-                errorPrint ("main: invalid strategy selection option (\"%c\")", argv[i][j]);
+                errorPrint ("main: invalid strategy selection option '%c'", argv[i][j]);
             }
           }
           break;
@@ -183,7 +183,7 @@ char *                      argv[])
           break;
         case 'V' :
           fprintf (stderr, "mord, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2004,2007,2008,2010,2011 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
           break;
@@ -199,14 +199,14 @@ char *                      argv[])
                 flagval |= C_FLAGVERBTIM;
                 break;
               default :
-                errorPrint ("main: unprocessed parameter \"%c\" in \"%s\"",
+                errorPrint ("main: unprocessed parameter '%c' in '%s'",
                             argv[i][j], argv[i]);
                 return     (1);
             }
           }
           break;
         default :
-          errorPrint ("main: unprocessed option (\"%s\")", argv[i]);
+          errorPrint ("main: unprocessed option '%s'", argv[i]);
           return     (1);
       }
     }
